<?php
$translations = array(
	'General_Locale' => 'lt_LT.UTF-8',
	'General_TranslatorName' => 'Donatas Stonys (Blue Whale SEO)',
	'General_TranslatorEmail' => 'info@teraxit.com',
	'General_EnglishLanguageName' => 'Lithuanian',
	'General_OriginalLanguageName' => 'Lietuvių',
	'General_HelloUser' => 'Sveiki, %s!',
	'General_OpenSourceWebAnalytics' => 'Atvirojo kodo žiniatinklio analizės sprendimas',
	'General_Dashboard' => 'Skydelis',
	'General_DashboardForASpecificWebsite' => 'Skydelis konkrečiai svetainei',
	'General_MultiSitesSummary' => 'Visos svetainės',
	'General_AllWebsitesDashboard' => 'Visų svetainių skydelis',
	'General_API' => 'API sąsaja',
	'General_Widgets' => 'Valdikliai',
	'General_Settings' => 'Nuostatos',
	'General_GiveUsYourFeedback' => 'Jūsų atsiliepimai!',
	'General_Unknown' => 'Nežinoma',
	'General_Never' => 'Naujesnis',
	'General_Required' => '%s reikalinga',
	'General_NotValid' => '%s nagaliojanti (-is)',
	'General_NotDefined' => '%s nenurodyta',
	'General_Id' => 'ID',
	'General_Error' => 'Klaida',
	'General_Warning' => 'Įspėjimas',
	'General_BackToHomepage' => 'Atgal į pradinį puslapį',
	'General_Yes' => 'Taip',
	'General_No' => 'Ne',
	'General_Delete' => 'Ištrinti',
	'General_Report' => 'Ataskaita',
	'General_Edit' => 'Redaguoti',
	'General_Download' => 'Atsisiųsti',
	'General_Upload' => 'Įkelti',
	'General_Ok' => 'Gerai',
	'General_Close' => 'Užverti',
	'General_OrCancel' => 'arba %s atšaukti %s',
	'General_Logout' => 'Atsijungti',
	'General_Username' => 'Naudotojo vardas',
	'General_Description' => 'Aprašymas',
	'General_Done' => 'Atlikta',
	'General_PoweredBy' => 'Įgaliota',
	'General_Name' => 'Pavadinimas',
	'General_Value' => 'Reikšmė',
	'General_Total' => 'Iš viso',
	'General_TotalVisitsActionsRevenue' => '(Iš viso: %s apsilankymų, %s veiksmų, %s pajamų)',
	'General_AverageOrderValue' => 'Vidutinė užsakymo vertė',
	'General_PurchasedProducts' => 'Įsigyta produkcija',
	'General_EcommerceOrders' => 'El. prekybos užsakymai',
	'General_AbandonedCarts' => 'Palikti krepšeliai',
	'General_TotalRevenue' => 'Pajamų iš viso',
	'General_ProductRevenue' => 'Pajamos iš produkto',
	'General_AveragePrice' => 'Vidutinė kaina',
	'General_AverageQuantity' => 'Vidutinis kiekis',
	'General_UniquePurchases' => 'Unikalūs pirkimai',
	'General_ProductConversionRate' => 'Produkto konversijos koeficientas',
	'General_Quantity' => 'Kiekis',
	'General_Price' => 'Kaina',
	'General_Subtotal' => 'Tarpinė suma',
	'General_Tax' => 'Mokesčiai',
	'General_Shipping' => 'Pristatymas',
	'General_Discount' => 'Nuolaida',
	'General_Details' => 'Išsamiau',
	'General_Default' => 'Pagal nutylėjimą',
	'General_Visit' => 'Apsilankymas',
	'General_FromReferrer' => 'nuo',
	'General_VisitorIP' => 'Lankytojo IP',
	'General_VisitorID' => 'Lankytojo ID',
	'General_VisitType' => 'Lankytojo tipas',
	'General_DaysSinceLastVisit' => 'Dienos nuo paskutinio apsilankymo',
	'General_DaysSinceFirstVisit' => 'Dienos nuo pirmo apsilankymo',
	'General_DaysSinceLastEcommerceOrder' => 'Dienos nuo paskutinio el. prekybos užsakymo',
	'General_NumberOfVisits' => 'Apsilankymų kiekis',
	'General_NewVisitor' => 'Naujas lankytojas',
	'General_ReturningVisitor' => 'Sugrįžtantis lankytojas',
	'General_Visitor' => 'Lankytojas',
	'General_Date' => 'Data',
	'General_Period' => 'Periodas',
	'General_ChooseDate' => 'Pasirinkti datą',
	'General_Today' => 'Šiandien',
	'General_Yesterday' => 'Vakar',
	'General_CurrentWeek' => 'Ši savaitė',
	'General_CurrentMonth' => 'Šis mėnuo',
	'General_CurrentYear' => 'Šie metai',
	'General_DateRange' => 'Laikotarpis:',
	'General_DateRangeInPeriodList' => 'Datos intervalas',
	'General_DateRangeFromTo' => 'Nuo %s iki %s',
	'General_ApplyDateRange' => 'Patvirtinti datos intervalą',
	'General_InvalidDateRange_js' => 'Netinkamas datos intervalas, prašome pabandyti dar kartą',
	'General_DateRangeFrom_js' => 'Nuo',
	'General_DateRangeTo_js' => 'Iki',
	'General_PreviousDays' => 'Praėjusios %s dienos (neįskaičiuojant šiandienos)',
	'General_LoadingData' => 'Įkeliami duomenys...',
	'General_Loading_js' => 'Įkeliama...',
	'General_GoTo' => 'Eiti į %s',
	'General_Next' => 'Pirmyn',
	'General_Previous' => 'Atgal',
	'General_First' => 'Pirmas',
	'General_Search' => 'Ieškoti',
	'General_Others' => 'Kita',
	'General_Table' => 'Lentelė',
	'General_Piechart' => 'Skritulinė diagrama',
	'General_TagCloud' => 'Žymių debesis',
	'General_VBarGraph' => 'Vertikalių stulpelių grafikas',
	'General_OpenInNewWindow_js' => 'Atidaryti naujame lange',
	'General_SaveImageOnYourComputer_js' => 'Norėdami išsaugoti paveikslėlį savo kompiuteryje, spustelėkite dešiniuoju pelytės klavišu ant paveikslėlio ir pasirinkite "Išsaugoti paveikslėlį kaip..."',
	'General_Refresh' => 'Atnaujinti puslapį',
	'General_Visitors' => 'Lankytojai',
	'General_ExportThisReport' => 'Eksportuoti šį duomenų rinkinį kitu formatu',
	'General_ExportAsImage_js' => 'Eksportuoti kaip paveikslėlį',
	'General_Export' => 'Eksportuoti',
	'General_YourChangesHaveBeenSaved' => 'Jūsų atlikti pakeitimai išsaugoti.',
	'General_ErrorRequest' => 'Oops… atsirado nesklandumų vykdant užklausą. Prašome pabandyti dar kartą.',
	'General_ColumnNbUniqVisitors' => 'Unikalūs lankytojai',
	'General_ColumnNbVisits' => 'Apsilankymai',
	'General_ColumnPercentageVisits' => '% apsilankymų',
	'General_ColumnNbActions' => 'Veiksmai',
	'General_NbActions' => 'Veiksmų kiekis',
	'General_ColumnMaxActions' => 'Daugiausia veiksmų per apsilankymą',
	'General_ColumnSumVisitLength' => 'Bendras visų lankytojų praleistas laikas (sekundėmis)',
	'General_ColumnLabel' => 'Žymė',
	'General_ColumnConversionRate' => 'Konversijų santykis',
	'General_ColumnActionsPerVisit' => 'Veiksmų per apsilankymą',
	'General_VisitDuration' => 'Vidutinė apsilankymo trukmė (sek.)',
	'General_ColumnAvgTimeOnSite' => 'Vidutinis laikas svetainėje',
	'General_ColumnAvgTimeOnSiteDocumentation' => 'Vidutinė apsilankymo trukmė',
	'General_ColumnVisitDuration' => 'Apsilankymo trukmė (sek.)',
	'General_ColumnBounceRate' => 'Šoklumo reitingas',
	'General_ColumnExitRate' => 'Pasišalinimo reitingas',
	'General_ColumnPageviews' => 'Puslapio peržiūros',
	'General_ColumnUniquePageviews' => 'Unikalios puslapio peržiūros',
	'General_ColumnBounces' => 'Šoklumas',
	'General_ColumnEntrances' => 'Užėjimai',
	'General_ColumnExits' => 'Išėjimai',
	'General_ColumnAverageTimeOnPage' => 'Vidutinis laikas puslapyje',
	'General_ColumnValuePerVisit' => 'Apsilankymo vertė',
	'General_ColumnVisitsWithConversions' => 'Apsilankymai su konversija',
	'General_YearsDays' => '%1$s metai %2$s dienos',
	'General_DaysHours' => '%1$s dienos %2$s valandos',
	'General_HoursMinutes' => '%1$s valandos %2$s min.',
	'General_MinutesSeconds' => '%1$s min. %2$ssek.',
	'General_Seconds' => '%ssek.',
	'General_Save' => 'Išsaugoti',
	'General_ForExampleShort' => 'pvz.',
	'General_YouMustBeLoggedIn' => 'Pirmiausia turite prisijungti.',
	'General_Website' => 'Svetainė',
	'General_GeneralSettings' => 'Pagrindiniai nustatymai',
	'General_AllowPiwikArchivingToTriggerBrowser' => 'Leisti Piwik archyvavimo trigerį, kai naršyklėje peržiūrimos ataskaitos',
	'General_ArchivingInlineHelp' => 'Vidutinio ir didelio srauto svetainėms rekomenduojama išjungti Piwik archyvavimo trigerį. Vietoj to, rekomenduojame nustatyti cron job Piwik ataskaitų generavimui kas valandą.',
	'General_ArchivingTriggerDescription' => 'Rekomenduojama didesniems Piwik diegimams. Jums reikia %snustatyti cron job%s automatiniam ataskaitų generavimui.',
	'General_SeeTheOfficialDocumentationForMoreInformation' => '%sOficialioje dokumentacijoje%s rasite daugiau informacijos.',
	'General_NSeconds' => '%s sekundės',
	'General_SmallTrafficYouCanLeaveDefault' => 'Mažo srauto svetainėms galite palikti numatytąsias %s sekundes ir gauti ataskaitas realiuoju laiku.',
	'General_MediumToHighTrafficItIsRecommendedTo' => 'Vidutinio ir didelio srauto svetainėms rekomenduojame generuoti kasdienines ataskaitas kas pusę valandos (%s sekundės) arba kas valandą (%s sekundės).',
	'General_RequiresFlash' => 'Grafikų atvaizdavimui reikalingas Flash',
	'General_GraphHelp' => 'Daugiau informacijos apie grafikų atvaizdavimą',
	'General_NoDataForGraph' => 'Šiam grafikui duomenų nėra',
	'General_NoDataForTagCloud' => 'Šiam žymių debesiui duomenų nėra',
	'General_DisplaySimpleTable' => 'Rodyti paprastą lentelę',
	'General_DisplayTableWithMoreMetrics' => 'Rodyti lentelę su daugiau duomenų',
	'General_DisplayTableWithGoalMetrics' => 'Rodyti lentelę su uždavinių duomenimis',
	'General_PiwikIsACollaborativeProjectYouCanContribute' => '%1$s Piwik %2$s yra bendras projektas. %3$s Jei Jums patinka Piwik, Jūs taip pat galite prisijungti! %4$s Kaip prisidėti prie Piwik? %5$s',
	'General_YouAreViewingDemoShortMessage' => 'Šiuo metu Jūs stebite Piwik demonstraciją',
	'General_DownloadFullVersion' => '%1$sAtsisiųskite%2$s pilną versiją! Išsamiau %3$s',
	'General_NewUpdatePiwikX' => 'Atnaujinimai: Piwik %s',
	'General_AboutPiwikX' => 'Apie Piwik %s',
	'General_PiwikXIsAvailablePleaseUpdateNow' => 'Išleista Piwik %1$s versija. %2$s Atnaujinkite dabar!%3$s (peržiūrėti %4$s pasikeitimus%5$s).',
	'General_PiwikXIsAvailablePleaseNotifyPiwikAdmin' => 'Pasirodė %s. Prašome pranešti svetainės administratoriui.',
	'General_NewReportsWillBeProcessedByCron' => 'Kai Piwik archyvavimas neaktyvuotas per naršyklę, naujos ataskaitos bus sugeneruotos per crontab',
	'General_ReportsWillBeProcessedAtMostEveryHour' => 'Todėl ataskaitos bus ruošiamos kas valandą.',
	'General_IfArchivingIsFastYouCanSetupCronRunMoreOften' => 'Jei manote, kad archyvavimas ir greitas Jūsų sistemoje, galite nustatyti crontab aktyvuotis dažniau.',
	'General_BackToPiwik' => 'Atgal į Piwik',
	'General_ClickHere' => 'Daugiau informacijos',
	'General_ShortMonth_1' => 'Sau',
	'General_ShortMonth_2' => 'Vas',
	'General_ShortMonth_3' => 'Kov',
	'General_ShortMonth_4' => 'Bal',
	'General_ShortMonth_5' => 'Geg',
	'General_ShortMonth_6' => 'Bir',
	'General_ShortMonth_7' => 'Lie',
	'General_ShortMonth_8' => 'Rgp',
	'General_ShortMonth_9' => 'Rgs',
	'General_ShortMonth_10' => 'Spa',
	'General_ShortMonth_11' => 'Lap',
	'General_ShortMonth_12' => 'Grd',
	'General_LongMonth_1' => 'Sausis',
	'General_LongMonth_2' => 'Vasaris',
	'General_LongMonth_3' => 'Kovas',
	'General_LongMonth_4' => 'Balandis',
	'General_LongMonth_5' => 'Gegužė',
	'General_LongMonth_6' => 'Birželis',
	'General_LongMonth_7' => 'Liepa',
	'General_LongMonth_8' => 'Rugpjūtis',
	'General_LongMonth_9' => 'Rugsėjis',
	'General_LongMonth_10' => 'Spalis',
	'General_LongMonth_11' => 'Lapkritis',
	'General_LongMonth_12' => 'Gruodis',
	'General_ShortDay_1' => 'Pir',
	'General_ShortDay_2' => 'Ant',
	'General_ShortDay_3' => 'Tre',
	'General_ShortDay_4' => 'Ket',
	'General_ShortDay_5' => 'Pen',
	'General_ShortDay_6' => 'Šeš',
	'General_ShortDay_7' => 'Sek',
	'General_LongDay_1' => 'Pirmadienis',
	'General_LongDay_2' => 'Antradienis',
	'General_LongDay_3' => 'Trečiadienis',
	'General_LongDay_4' => 'Ketvirtadienis',
	'General_LongDay_5' => 'Penktadienis',
	'General_LongDay_6' => 'Šeštadienis',
	'General_LongDay_7' => 'Sekmadienis',
	'General_Daily' => 'Kasdien',
	'General_Weekly' => 'Kas savaitę',
	'General_Monthly' => 'Kas mėnesį',
	'General_ConfigFileIsNotWritable' => 'Piwik konfigūracijos failas %s negali būti keičiamas, todėl dalis Jūsų nustatymų gali būti neišsaugoti. %s Prašome pakeisti šio failo teises, kad galėtumėte įrašyti pakeitimus.',
	'General_ExceptionDatabaseVersion' => 'Jūsų %1$s versija yra %2$s, tačiau Piwik reikalinga bent jau %3$s.',
	'General_ExceptionIncompatibleClientServerVersions' => 'Jūsų %1$s kliento versija yra %2$s, kuri yra nesuderinama su serverio %3$s versija.',
	'General_ExceptionMissingFile' => 'Trūksta failo: %s',
	'General_ExceptionFilesizeMismatch' => 'Nesutampa failo dydis: %1$s (turi būti: %2$s, rasta: %3$s)',
	'General_ExceptionFileIntegrity' => 'Nesėkminga vientisumo patikra: %s',
	'General_ExceptionNonceMismatch' => 'Negalima patikrinti šios formos saugos rakto.',
	'General_PleaseSpecifyValue' => 'Prašome nurodyti \'%s\' reikšmę.',
	'General_ExceptionMethodNotFound' => '\'%s\' metodas neegzistuoja arba neprieinamas \'%s\' modulyje.',
	'General_ExceptionInvalidRendererFormat' => 'Verčiamas formatas \'%s\' negaliojantis . Vietoj jo pabandykite šiuos: %s.',
	'General_ExceptionInvalidPeriod' => 'Periodas \'%s\' nepalaikomas. Vietoj jo pabandykite šiuos: %s.',
	'General_ExceptionInvalidDateRange' => 'Data \'%s\' yra iš klaidingo diapazono. Ji turi būti šio formato: %s.',
	'General_ExceptionGoalNotFound' => 'Uždavinio id = %s nerastas.',
	'General_ExceptionUndeletableFile' => 'Nepavyko ištrinti %s',
	'General_ExceptionPrivilege' => 'Negalite pasiekti šių resursų, nes tam reikia %s teisių.',
	'General_ExceptionPrivilegeAtLeastOneWebsite' => 'Negalite pasiekti šių resursų, nes tam reikia %s teisių mažiausiai vienai svetainei.',
	'General_ExceptionPrivilegeAccessWebsite' => 'Negalite pasiekti šių resursų, nes tam reikia %s teisių svetainei id = %d..',
	'General_ExceptionInvalidArchiveTimeToLive' => 'Šiandienos archyvo saugojimo laikas turi būti nurodytas sekundėmis ir reikšme didesne už nulį',
	'General_ExceptionConfigurationFileNotFound' => '{%s} konfigūracijos failas nerastas.',
	'General_ExceptionUnreadableFileDisabledMethod' => '{%s} konfigūracijos failas nenuskaitytas. Jūsų stotis gali būti išjungusi %s.',
	'General_ExceptionInvalidToken' => 'Pažymėjimas negaliojantis.',
	'General_ExceptionInvalidDateFormat' => 'Datos formatas turi būti: %s ar bet kuris raktažodis palaikomas %s funkcijos (žiūrėkite %s išsamesnei informacijai gauti)',
	'General_ExceptionLanguageFileNotFound' => '\'%s\' kalbos failas nerastas.',
	'General_ExceptionUnableToStartSession' => 'Nepavyko pradėti sesijos',
	'General_WarningFileIntegritySkipped' => 'Aptikta tobulinimo aplinka. Praleidžiamas vientisumo tikrinimas.',
	'General_WarningFileIntegrityNoManifest' => 'Failo vientisumo patikra negali būti atlikta dėl nesamo manifest.inc.php failo.',
	'General_WarningFileIntegrityNoMd5file' => 'Failo vientisumo patikra negali būti atlikta dėl nesamos md5_file() funkcijos.',
	'General_FileIntegrityWarningExplanation' => 'Failo vientisumo patikra nutraukta ir pateikiama klaidų ataskaita. Tikėtina, jog tai įtakoja nepilnas arba nutrauktas Piwik failų įkėlimas į serverį. Prašome pabandyti pakartotinai perkelti Piwik failus ir atnaujinti šį puslapį kol nebebus rodomi klaidų pranešimai.',
	'General_UseSMTPServerForEmail' => 'Naudoti SMTP serverį pašto siuntimui',
	'General_SmtpServerAddress' => 'SMTP serverio adresas',
	'General_SmtpPort' => 'SMTP prievadas',
	'General_AuthenticationMethodSmtp' => 'SMTP autentifikacijos metodas',
	'General_SmtpUsername' => 'SMTP naudotojo vardas',
	'General_SmtpPassword' => 'SMTP slaptažodis',
	'General_SmtpEncryption' => 'SMTP šifravimas',
	'General_SelectYesIfYouWantToSendEmailsViaServer' => 'Pažymėkite "Taip", jei norite, kad laiškai būtų siunčiami per vardinį serverį vietoj vietinės siuntimo funkcijos.',
	'General_OnlyUsedIfUserPwdIsSet' => 'Tik kai nurodomas naudotojo vardas/slaptažodis. Klauskite savo paslaugų teikėjo, jei nesate tikri, kurį metodą naudoti.',
	'General_OnlyEnterIfRequired' => 'Įveskite naudotojo vardą tik jei Jūsų SMTP serveris to reikalauja',
	'General_OnlyEnterIfRequiredPassword' => 'Įveskite slaptažodį tik jei Jūsų SMTP serveris to reikalauja',
	'General_WarningPasswordStored' => '%sĮspėjimas:%s Šis slaptažodis bus išsaugotas konfigūracijos faile, kuris bus matomas kiekvienam turinčiam priėjimą prie šio failo.',
	'General_InvalidResponse' => 'Gauti netinkami duomenys.',
	'General_ChooseLanguage' => 'Pasirinkti kalbą',
	'General_ChoosePeriod' => 'Pasirinkti periodą',
	'General_ChooseWebsite' => 'Pasirinkti svetainę',
	'General_Language' => 'Kalba',
	'General_PleaseUpdatePiwik' => 'Prašome atnaujinti Piwik',
	'General_RequestTimedOut' => 'Duomenų paklausimas %s baigėsi. Prašome pabandyti dar kartą.',
	'General_Recommended' => '(rekomenduojama)',
	'General_Goal' => 'Uždavinys',
	'General_Help' => 'Pagalba',
	'Actions_PluginDescription' => 'Puslapių peržiūros, išorinių nuorodų ir atsisiuntimų ataskaitos. Išorinių nuorodų ir atsisiuntimų stebėjimas yra įgalinamas automatiškai!',
	'Actions_Actions' => 'Veiksmai',
	'Actions_SubmenuPages' => 'Puslapiai',
	'Actions_SubmenuPagesEntry' => 'Užėjimo puslapiai',
	'Actions_SubmenuPagesExit' => 'Išėjimo puslapiai',
	'Actions_SubmenuPageTitles' => 'Puslapių antraštės',
	'Actions_SubmenuOutlinks' => 'Išorinės nuorodos',
	'Actions_SubmenuDownloads' => 'Atsisiuntimai',
	'Actions_ColumnClicks' => 'Paspaudimai',
	'Actions_ColumnUniqueClicks' => 'Unikalūs paspaudimai',
	'Actions_ColumnDownloads' => 'Atsisiuntimai',
	'Actions_ColumnUniqueDownloads' => 'Unikalūs atsisiuntimai',
	'Actions_ColumnPageName' => 'Puslapio pavadinimas',
	'Actions_ColumnPageURL' => 'Puslapio URL',
	'Actions_ColumnClickedURL' => 'Paspausti URL',
	'Actions_ColumnDownloadURL' => 'Atsisiuntimų URL',
	'AnonymizeIP_PluginDescription' => 'Paslėpkite savo lankytojų IP adresus, jei to reikalauja Jūsų vidaus taisyklės ar įstatymai.',
	'API_PluginDescription' => 'Visi duomenys Piwik pasiekiami per paprastas API sąsajas. Šis papildinys - tai žiniatinklio tarnybos įėjimo taškas, kuriuo galite naudotis norėdami gauti savo žiniatinklio analizatoriaus duomenis xml, json, php, csv ir kitais formatais.',
	'API_QuickDocumentationTitle' => 'API trumpa dokumentacija',
	'API_GenerateVisits' => 'Jei neturite duomenų šiandienai , galite sugeneruoti jų pasinaudoję %s papildiniu. Įjunkite šį %s papildinį, tada spauskite ant \'Apsilankymų generatorius\' meniu Piwik administratoriaus srityje.',
	'API_MoreInformation' => 'Norinčius gauti daugiau informacijos apie Piwik API sąsajas, prašome žvilgtelėti į %s Įvadas į Piwik API %s ir %s Piwik API informacija %s.',
	'API_UserAuthentication' => 'Naudotojo autentifikavimas',
	'API_UsingTokenAuth' => 'Jei norite %s gauti duomenis scenarijų, crontab ir pan. įrankių pagalba, %s turite pridėti parametrus %s į API užklausų URLs, kurios reikalauja autentifikacijos.',
	'API_KeepTokenSecret' => 'Šis token_auth yra slaptas kaip ir naudotojo vardas bei slaptažodis, %s neviešinkite jo%s!',
	'API_LoadedAPIs' => 'Sėkmingai įkrautos API sąsajos (%s).',
	'CoreAdminHome_PluginDescription' => 'Piwik administravimo sritis',
	'CoreAdminHome_MenuGeneralSettings' => 'Pagrindiniai nustatymai',
	'CoreAdminHome_Administration' => 'Administravimas',
	'PrivacyManager_TeaserHeadline' => 'Privatumo nustatymai',
	'PrivacyManager_MenuPrivacySettings' => 'Privatumas',
	'PrivacyManager_UseAnonymizeIp' => 'Paslėpti lankytojų IP adresus',
	'PrivacyManager_DeleteLogsOlderThan' => 'Ištrinti įrašus senesnius nei',
	'PrivacyManager_DeleteMaxRows' => 'Maksimalus vienu metu trinamų eilučių kiekis:',
	'PrivacyManager_LastDelete' => 'Paskutinis išvalymas atliktas',
	'PrivacyManager_NextDelete' => 'Kitas suplanuotas išvalymas',
	'CoreHome_PluginDescription' => 'Žiniatinklio analizės sprendimo ataskaitų struktūra.',
	'CoreHome_WebAnalyticsReports' => 'Žiniatinklio analizės sprendimo ataskaitos',
	'CoreHome_JavascriptDisabled' => 'JavaScript turi būti įjungta, kad būtų galima naudoti standartinę Piwik išvaizdą.<br />Tačiau panašu, kad JavaScript yra arba išjungta, arba nepalaikoma Jūsų naršyklės.<br />Norėdami matyti standartinę išvaizdą, įjunkite JavaScript keisdami savo naršyklės nustatymus, tada %1$sbandykite dar kartą%2$s.<br />',
	'CoreHome_ThereIsNoDataForThisReport' => 'Nėra duomenų šiai ataskaitai.',
	'CoreHome_CategoryNoData' => 'Šioje kategorijoje duomenų nėra. Pabandykite "Įtraukti visą populiaciją"',
	'CoreHome_ShowJSCode' => 'Parodyti JavaScript kodą įvedimui',
	'CoreHome_PageOf_js' => '%1$s iš %2$s',
	'CoreHome_PeriodDay' => 'Diena',
	'CoreHome_PeriodWeek' => 'Savaitė',
	'CoreHome_PeriodMonth' => 'Mėnuo',
	'CoreHome_PeriodYear' => 'Metai',
	'CoreHome_PeriodDays' => 'dienos',
	'CoreHome_PeriodWeeks' => 'savaitės',
	'CoreHome_PeriodMonths' => 'mėnesiai',
	'CoreHome_PeriodYears' => 'metai',
	'CoreHome_DaySu_js' => 'Se',
	'CoreHome_DayMo_js' => 'Pi',
	'CoreHome_DayTu_js' => 'An',
	'CoreHome_DayWe_js' => 'Tr',
	'CoreHome_DayTh_js' => 'Kt',
	'CoreHome_DayFr_js' => 'Pn',
	'CoreHome_DaySa_js' => 'Št',
	'CoreHome_ShortDay_1_js' => 'Sek',
	'CoreHome_ShortDay_2_js' => 'Pir',
	'CoreHome_ShortDay_3_js' => 'Ant',
	'CoreHome_ShortDay_4_js' => 'Tre',
	'CoreHome_ShortDay_5_js' => 'Ket',
	'CoreHome_ShortDay_6_js' => 'Pen',
	'CoreHome_ShortDay_7_js' => 'Šeš',
	'CoreHome_LongDay_1_js' => 'Sekmadienis',
	'CoreHome_LongDay_2_js' => 'Pirmadienis',
	'CoreHome_LongDay_3_js' => 'Antradienis',
	'CoreHome_LongDay_4_js' => 'Trečiadienis',
	'CoreHome_LongDay_5_js' => 'Ketvirtadienis',
	'CoreHome_LongDay_6_js' => 'Penktadienis',
	'CoreHome_LongDay_7_js' => 'Šeštadienis',
	'CoreHome_ShortMonth_1_js' => 'Sau',
	'CoreHome_ShortMonth_2_js' => 'Vas',
	'CoreHome_ShortMonth_3_js' => 'Kov',
	'CoreHome_ShortMonth_4_js' => 'Bal',
	'CoreHome_ShortMonth_5_js' => 'Geg',
	'CoreHome_ShortMonth_6_js' => 'Bir',
	'CoreHome_ShortMonth_7_js' => 'Lie',
	'CoreHome_ShortMonth_8_js' => 'Rgp',
	'CoreHome_ShortMonth_9_js' => 'Rgs',
	'CoreHome_ShortMonth_10_js' => 'Spa',
	'CoreHome_ShortMonth_11_js' => 'Lap',
	'CoreHome_ShortMonth_12_js' => 'Grd',
	'CoreHome_MonthJanuary_js' => 'Sausis',
	'CoreHome_MonthFebruary_js' => 'Vasaris',
	'CoreHome_MonthMarch_js' => 'Kovas',
	'CoreHome_MonthApril_js' => 'Balandis',
	'CoreHome_MonthMay_js' => 'Gegužė',
	'CoreHome_MonthJune_js' => 'Birželis',
	'CoreHome_MonthJuly_js' => 'Liepa',
	'CoreHome_MonthAugust_js' => 'Rugpjūtis',
	'CoreHome_MonthSeptember_js' => 'Rugsėjis',
	'CoreHome_MonthOctober_js' => 'Spalis',
	'CoreHome_MonthNovember_js' => 'Lapkritis',
	'CoreHome_MonthDecember_js' => 'Gruodis',
	'CorePluginsAdmin_PluginDescription' => 'Papildinių administravimo sąsaja.',
	'CorePluginsAdmin_Plugins' => 'Papildiniai',
	'CorePluginsAdmin_PluginsManagement' => 'Papildinių valdymas',
	'CorePluginsAdmin_MainDescription' => 'Papildiniai suteikia Piwik papildomų galimybių. Įdiegę papildinį, čia galite jį aktyvinti arba pasyvinti',
	'CorePluginsAdmin_Plugin' => 'Papildinys',
	'CorePluginsAdmin_Version' => 'Versija',
	'CorePluginsAdmin_Status' => 'Būsena',
	'CorePluginsAdmin_Action' => 'Veiksmas',
	'CorePluginsAdmin_PluginHomepage' => 'Papildinio svetainė',
	'CorePluginsAdmin_Activated' => 'Aktyvintas',
	'CorePluginsAdmin_Active' => 'Aktyvus',
	'CorePluginsAdmin_Inactive' => 'Pasyvus',
	'CorePluginsAdmin_Deactivate' => 'Pasyvinti',
	'CorePluginsAdmin_Activate' => 'Aktyvinti',
	'CorePluginsAdmin_MenuPlugins' => 'Papildiniai',
	'CoreUpdater_PluginDescription' => 'Piwik naujinimo įranga',
	'CoreUpdater_UpdateTitle' => 'Naujinimas',
	'CoreUpdater_DatabaseUpgradeRequired' => 'Reikalingas duombazės atnaujinimas',
	'CoreUpdater_YourDatabaseIsOutOfDate' => 'Norint tęsti, reikia atnaujinti Piwik duombazę',
	'CoreUpdater_PiwikWillBeUpgradedFromVersionXToVersionY' => 'Piwik duombazė bus atnaujinta iš %1$s į %2$s versiją.',
	'CoreUpdater_TheFollowingPluginsWillBeUpgradedX' => 'Bus atnaujinti šie papildiniai: %s.',
	'CoreUpdater_NoteForLargePiwikInstances' => 'Svarbi pastaba apie didelius Piwik diegimus',
	'CoreUpdater_TheUpgradeProcessMayFailExecuteCommand' => 'Jei Jūsų Piwik duombazė yra didelė, atnaujinimas naršyklėje gali užtrukti per ilgai. Tokiu atveju, galite paleisti atnaujinimus per komandinę eilutę: %s',
	'CoreUpdater_YouCouldManuallyExecuteSqlQueries' => 'Jei negalite pasinaudoti komandine eilute Piwik atnaujinti ar Piwik tiesiog neatsinaujina (dėl nutrūkusios sesijos, prarasto ryšio su duombaze ar kurios nors kitos priežasties), galite rankiniu būdu įvykdyti SQL užklausas Piwik atnaujinimui.',
	'CoreUpdater_ClickHereToViewSqlQueries' => 'Spauskite čia SQL užklausų, kurias reikia įvykdyti, sąrašui gauti.',
	'CoreUpdater_NoteItIsExpectedThatQueriesFail' => 'Pastaba: jei rankiniu būdu įvykdysite šias užklausas, gali būti, jog kai kurios iš jų praneš apie klaidas ir nebus įvykdytos. Paprasčiausias ignoruokite klaidas ir vykdykite sekančias užklausas esančias sąraše.',
	'CoreUpdater_ReadyToGo' => 'Pasiruošę pradėti?',
	'CoreUpdater_TheUpgradeProcessMayTakeAWhilePleaseBePatient' => 'Duombazės naujinimo procesas gali užtrukti, todėl prašome luktelėti.',
	'CoreUpdater_UpgradePiwik' => 'Naujinti Piwik',
	'CoreUpdater_ErrorDIYHelp' => 'Jei Jūs esate patyręs vartotojas ir susidūrėte su problema atnaujinant duombazę:',
	'CoreUpdater_ErrorDIYHelp_1' => 'nustatykite ir pakoreguokite problemos šaltinį (pvz., memory_limit arba max_execution_time)',
	'CoreUpdater_ErrorDIYHelp_2' => 'paleiskite likusias užklausas nepavykusiame naujinime',
	'CoreUpdater_ErrorDIYHelp_3' => 'rankiniu būdu papildykite `option` lentelę Piwik duombazėje, nustatydami version_core reikšmę į nepavykusio naujinimo versijos numerį',
	'CoreUpdater_ErrorDIYHelp_4' => 'paleiskite naujinimo procesą iš naujo (naršyklėje arba iš komandinės eilutės) ir pratęskite likusius atnaujinimus',
	'CoreUpdater_ErrorDIYHelp_5' => 'praneškite apie problemą (ir sprendimą), kad Piwik būtų patobulintas',
	'CoreUpdater_HelpMessageContent' => 'Peržiūrėkite %1$s Piwik DUK, %2$s kur paaiškinamos dažniausiai pasitaikančios naujinimo problemos. %3$s Jūsų sistemos administratorius gali padėti išspręsti daugumą jų, kadangi jos dažniausiai susijusios su serverio arba MySQL nustatymais.',
	'CoreUpdater_CriticalErrorDuringTheUpgradeProcess' => 'Kritinė klaida atnaujinimo metu:',
	'CoreUpdater_HelpMessageIntroductionWhenError' => 'Aukščiau nurodytas klaidos aprašymas. Jei reikia daugiau pagalbos:',
	'CoreUpdater_HelpMessageIntroductionWhenWarning' => 'Piwik atnaujinta, tačiau su išlygomis. Prašome perskaityti aukščiau pateikiamą aprašymą. Jei reikia daugiau pagalbos:',
	'CoreUpdater_UpgradeComplete' => 'Naujinimas baigtas!',
	'CoreUpdater_WarningMessages' => 'Įspėjamieji pranešimai:',
	'CoreUpdater_ErrorDuringPluginsUpdates' => 'Klaida atnaujinant papildinius:',
	'CoreUpdater_WeAutomaticallyDeactivatedTheFollowingPlugins' => 'Automatiškai pasyvinome šiuos papildinius: %s',
	'CoreUpdater_PiwikHasBeenSuccessfullyUpgraded' => 'Piwik sėkmingai atnaujinta!',
	'CoreUpdater_ContinueToPiwik' => 'Grįžti į Piwik',
	'CoreUpdater_UpdateAutomatically' => 'Naujinti automatiškai',
	'CoreUpdater_ThereIsNewVersionAvailableForUpdate' => 'Pasirodė nauja Piwik versija',
	'CoreUpdater_YouCanUpgradeAutomaticallyOrDownloadPackage' => 'Galite atnaujinti iki %s versijos automatiškai arba atsisiųsti paketą ir atnaujinti Piwik rankiniu būdu:',
	'CoreUpdater_YouMustDownloadPackageOrFixPermissions' => 'Piwik negali perrašyti Jūsų dabartinio diegimo. Galite arba pataisyti katalogo/failo teises, arba atsisiųsti paketą ir įdiegti šią versiją %s rankiniu būdu:',
	'CoreUpdater_DownloadX' => 'Atsisiųsti %s',
	'CoreUpdater_UpdateHasBeenCancelledExplanation' => 'Piwik automatinis atnaujinimas atšauktas. Jei negalite ištaisyti nurodytos klaidos, rekomenduojame atnaujinti Piwik rankiniu būdu. %1$s Peržiūrėkite %2$sNaujinimo dokumentaciją%3$s prieš pradedant!',
	'CoreUpdater_DownloadingUpdateFromX' => 'Atsisiunčiamas atnaujinimas iš %s',
	'CoreUpdater_UnpackingTheUpdate' => 'Išskleidžiama',
	'CoreUpdater_VerifyingUnpackedFiles' => 'Tikrinami išskleisti failai',
	'CoreUpdater_CreatingBackupOfConfigurationFile' => 'Sukuriama atsarginė konfigūracijos failų kopija %s',
	'CoreUpdater_InstallingTheLatestVersion' => 'Įdiegiama naujausia versija',
	'CoreUpdater_PiwikUpdatedSuccessfully' => 'Piwik sėkmingai atnaujinta!',
	'CoreUpdater_EmptyDatabaseError' => 'Duombazė %s yra tuščia. Privalote paredaguoti arba pašalinti savo Piwik konfigūracijos failą.',
	'CoreUpdater_ExceptionAlreadyLatestVersion' => 'Jūsų Piwik versija %s yra naujausia.',
	'CoreUpdater_ExceptionArchiveIncompatible' => 'Nesuderinamas archyvas: %s',
	'CoreUpdater_ExceptionArchiveEmpty' => 'Tuščias archyvas',
	'CoreUpdater_ExceptionArchiveIncomplete' => 'Archyvas nepilnas: trūksta kai kurių failų (pvz. %s).',
	'Dashboard_PluginDescription' => 'Jūsų žiniatinklio analizės sprendimo skydelis. Galite pritaikyti skydelį savo poreikiams: pridėti naujų valdiklių, pakeisti jų išdėstymo tvarką. Kiekvienas naudotojas gali susikurti savo asmeninį skydelį.',
	'Dashboard_Dashboard' => 'Skydelis',
	'Dashboard_DeleteWidgetConfirm' => 'Ar tikrai norite pašalinti šį valdiklį iš skydelio?',
	'Dashboard_SelectWidget' => 'Pasirinkite valdiklį, kurį norite įdėti į skydelį',
	'Dashboard_AddPreviewedWidget_js' => 'Įdėti peržiūrėtą valdiklį į skydelį',
	'Dashboard_WidgetPreview_js' => 'Valdiklio peržiūra',
	'Dashboard_Close_js' => 'Užverti',
	'Dashboard_Maximise_js' => 'Padidinti',
	'Dashboard_TitleWidgetInDashboard_js' => 'Valdiklis jau skydelyje',
	'Dashboard_TitleClickToAdd_js' => 'Spustelėkite įdėjimui į skydelį',
	'Dashboard_LoadingWidget_js' => 'Įkeliamas valdiklis, luktelėkite...',
	'Dashboard_WidgetNotFound_js' => 'Valdiklis nerastas',
	'DBStats_PluginDescription' => 'Šis papildinys informuoja apie MySQL duombazės užimtumą.',
	'DBStats_DatabaseUsage' => 'Duombazės naudojimas',
	'DBStats_MainDescription' => 'Piwik saugo visus Jūsų duomenis MySQL duombazėje. Šiuo metu Piwik lentelės naudoja %s.',
	'DBStats_LearnMore' => 'Norint geriau susipažinti su Piwik duomenų apdorojimu bei kaip priversti Piwik veikti geriau vidutinės ir didelės apkrovos svetainėse, siūlome pastudijuoti dokumentaciją %s.',
	'DBStats_Table' => 'Lentelė',
	'DBStats_RowCount' => 'Eilučių kiekis',
	'DBStats_DataSize' => 'Informacijos kiekis',
	'DBStats_IndexSize' => 'Indekso dydis',
	'DBStats_TotalSize' => 'Bendras dydis',
	'ExampleAPI_PluginDescription' => 'Pavyzdinis papildinys: Kaip sukurti API sąsają jūsų papildiniui, kad būtų galima eksportuoti duomenis daugeliu formatų be papildomo programavimo?',
	'ExampleFeedburner_PluginDescription' => 'Pavyzdinis papildinys: Kaip pavaizduoti jūsų Feedburner prenumeratą skydelio valdiklyje?',
	'ExampleRssWidget_PluginDescription' => 'Pavyzdinis papildinys: Kaip sukurti naują valdiklį, kuris skaito RSS santraukas?',
	'ExampleUI_PluginDescription' => 'Pavyzdinis papildinys: Šis papildinys parodys kaip dirbti su Piwik UI: kurti lenteles, grafikus ir pan.',
	'Feedback_PluginDescription' => 'Siųskite savo atsiliepimus Piwik komandai. Dalinkitės savo idėjomis ir pasiūlymais su mumis!',
	'Feedback_DoYouHaveBugReportOrFeatureRequest' => 'Norite pranešti apie aptiktą klaidą arba paprašyti naujų ypatybių?',
	'Feedback_ViewAnswersToFAQ' => 'Peržiūrėkite atsakymus į %s dažniausiai užduodamus klausimus%s',
	'Feedback_WhyAreMyVisitsNoTracked' => 'Kodėl nestebimi apsilankymai mano svetainėje?',
	'Feedback_HowToExclude' => 'Kaip neįtraukti savo apsilankymų?',
	'Feedback_WhyWrongCountry' => 'Kodėl Piwik rodo mano apsilankymus ne iš tos šalies?',
	'Feedback_HowToAnonymizeIP' => 'Kaip paslėpti lankytojų IP adresus mano duombazėje?',
	'Feedback_VisitTheForums' => 'Apsilankykite %s forumuose%s',
	'Feedback_LearnWaysToParticipate' => 'Sužinokite kaip galite %s prisijungti%s',
	'Feedback_SpecialRequest' => 'Gal turite specialių pageidavimų Piwik komandai?',
	'Feedback_ContactThePiwikTeam' => 'Susisiekite su Piwik komanda!',
	'Feedback_IWantTo' => 'Aš noriu:',
	'Feedback_CategoryShareStory' => 'Pasidalinkite Piwik sėkmės istorija',
	'Feedback_CategorySponsor' => 'Paremkite Piwik',
	'Feedback_CategoryHire' => 'Nusisamdykite Piwik konsultantą',
	'Feedback_CategorySecurity' => 'Praneškite apie saugumo spragą',
	'Feedback_MyEmailAddress' => 'Mano el. pašto adresas:',
	'Feedback_MyMessage' => 'Mano žinutė:',
	'Feedback_DetailsPlease' => '(prašome detaliau)',
	'Feedback_SendFeedback' => 'Siųsti atsiliepimą',
	'Feedback_ManuallySendEmailTo' => 'Prašome išsiųsti rankiniu būdu',
	'Feedback_MessageSent' => 'Jūsų žinutė buvo nusiųsta Piwik komandai.',
	'Feedback_ThankYou' => 'Dėkojame už pagalbą kuriant tobulesnį Piwik!',
	'Feedback_ThePiwikTeam' => 'Piwik komanda',
	'Feedback_ExceptionBodyLength' => 'Žinutė privalo būti mažiausiai %s simbolių ilgio.',
	'Feedback_ExceptionNoUrls' => 'Žinutės tekste negali būti interneto adresų (URL) siekiant išvengti brukalų.',
	'Goals_Goals' => 'Uždaviniai',
	'Goals_GoalsOverview' => 'Uždavinių apžvalga',
	'Goals_GoalsManagement' => 'Uždavinių valdymas',
	'Goals_PluginDescription' => 'Sukurkite uždavinius ir stebėkite ataskaitas apie uždavinių konversijas: raidą per laikotarpį, vizito pajamas, nuorodų, raktažodžių konversijas ir t.t.',
	'Goals_ColumnConversions' => 'Konversijos',
	'Goals_ColumnRevenue' => 'Pajamos',
	'Goals_GoalX' => 'Uždavinys %s',
	'Goals_OverallRevenue' => '%s bendros pajamos',
	'Goals_OverallConversionRate' => '%s bendras konversijos koeficientas (apsilankymai su uždavinio užbaigimu)',
	'Goals_Conversions' => '%s konversijos',
	'Goals_ConversionRate' => '%s konversijos koeficientas',
	'Goals_NoGoalsNeedAccess' => 'Tik administratorius ir super naudotojas gali pridėti uždavinius nurodytoms svetainėms. Paprašykite savo Piwik administratoriaus pridėti uždavinį Jūsų svetainei. <br> Uždavinių stebėjimas yra puikus būdas suprasti ir maksimizuoti Jūsų svetainės įdirbį!',
	'Goals_AddNewGoal' => 'Pridėti naują uždavinį',
	'Goals_AddNewGoalOrEditExistingGoal' => '%sPridėti naują uždavinį%s arba %sRedaguoti%s jau egzistuojantį',
	'Goals_AddGoal_js' => 'Pridėti uždavinį',
	'Goals_UpdateGoal_js' => 'Atnaujinti uždavinį',
	'Goals_DeleteGoalConfirm_js' => 'Ar tikrai norite ištrinti uždavinį %s?',
	'Goals_CreateNewGOal' => 'Sukurti naują uždavinį',
	'Goals_ViewAndEditGoals' => 'Peržiūrėti ir redaguoti uždavinius',
	'Goals_GoalName' => 'Uždavinio pavadinimas',
	'Goals_GoalIsTriggered' => 'Uždavinys paleistas',
	'Goals_GoalIsTriggeredWhen' => 'Uždavinys paleistas kai',
	'Goals_WhenVisitors' => 'kai lankytojai',
	'Goals_WhereThe' => 'kur',
	'Goals_Manually' => 'rankiniu būdu',
	'Goals_ManuallyTriggeredUsingJavascriptFunction' => 'Uždavinys paleistas rankiniu būdu naudojantis JavaScript API trackGoal()',
	'Goals_VisitUrl' => 'Aplankyti pateiktą URL (puslapį ar puslapių grupę)',
	'Goals_URL' => 'URL',
	'Goals_Filename' => 'failo pavadinimas',
	'Goals_ExternalWebsiteUrl' => 'išorinės svetainės URL',
	'Goals_Download' => 'Atsisiųsti failą',
	'Goals_ClickOutlink' => 'Paspauskite ant nuorodos į išorinį puslapį',
	'Goals_Optional' => '(papildoma)',
	'Goals_DefaultRevenue' => 'Numatytosios uždavinio pajamos yra',
	'Goals_DefaultRevenueHelp' => 'Pavyzdžiui, lankytojo užpildyta ir išsiųsta kontaktinė forma gali būti verta vidutiniškai 10 Lt. Piwik padės Jums suprasti Jūsų lankytojų segmentų efektyvumą.',
	'Goals_ConversionsOverview' => 'Konversijų apžvalga',
	'Goals_BestCountries' => 'Jūsų geriausios konversijos šalys:',
	'Goals_BestKeywords' => 'Jū9sų geriausi konversijos raktažodžiai:',
	'Goals_BestReferers' => 'Jūsų geriausios konversijos svetainės:',
	'Goals_ReturningVisitorsConversionRateIs' => 'Sugrįžtančių lankytojų konversijos koeficientas yra %s',
	'Goals_NewVisitorsConversionRateIs' => 'Naujų lankytojų konversijos koeficientas yra %s',
	'Goals_Contains' => 'turi %s',
	'Goals_IsExactly' => 'yra tiksliai %s',
	'Goals_MatchesExpression' => 'atitinka išraišką %s',
	'Goals_CaseSensitive' => 'Linksnių atitikimas',
	'Goals_Pattern' => 'Derinys',
	'Goals_ExceptionInvalidMatchingString' => 'Jei pasirinksite "tikslų atitikimą", tinkanti reikšmė turi būti URL prasidedanti %s. Pavyzdžiui, \'%s\'.',
	'Goals_LearnMoreAboutGoalTrackingDocumentation' => 'Sužinokite daugiau apie %s uždavinių stebėjimą Piwik%s naudotojo dokumentacijoje.',
	'Installation_PluginDescription' => 'Piwik diegimo procesas. Diegimas paprastai atliekamas vieną kartą. Jei konfigūracijos failas config/config.inc.php ištrinamas, bus paleistas papildomas diegimas.',
	'Installation_Installation' => 'Įdiegimas',
	'Installation_InstallationStatus' => 'Įdiegimo būklė',
	'Installation_PercentDone' => '%s %% Atlikta',
	'Installation_NoConfigFound' => 'Jūs bandote pasiekti Piwik puslapį, tačiau negalima rasti Piwik konfigūracinio failo.<br /><b>  » Galite <a href=\'index.php\'>įdiegti Piwik dabar</a></b><br /><small>Jei Piwik duombazėje liko lentelių iš ankstesnių diegimų, nesijaudinkite, nes galite naudoti tas pačias lenteles ir išsaugoti turimus duomenis!</small>',
	'Installation_DatabaseSetup' => 'Duombazės sąranka',
	'Installation_DatabaseSetupServer' => 'duomenų bazių serveris',
	'Installation_DatabaseSetupLogin' => 'prisijungimas',
	'Installation_DatabaseSetupPassword' => 'slaptažodis',
	'Installation_DatabaseSetupDatabaseName' => 'duomenų bazės pavadinimas',
	'Installation_DatabaseSetupTablePrefix' => 'lentelės priešdėlis',
	'Installation_DatabaseSetupAdapter' => 'suderintuvas',
	'Installation_DatabaseErrorConnect' => 'Klaida jungiantis prie duombazės serverio',
	'Installation_DatabaseCheck' => 'Duomenų bazės patikra',
	'Installation_DatabaseServerVersion' => 'Duomenų bazių serverio versija',
	'Installation_DatabaseClientVersion' => 'Duomenų bazės kliento versija',
	'Installation_DatabaseCreation' => 'Duomenų bazės sukūrimas',
	'Installation_PleaseFixTheFollowingErrors' => 'Prašome ištaisyti šias klaidas',
	'Installation_LargePiwikInstances' => 'Pagalba dideliems Piwik pavyzdžiams',
	'Installation_JsTag' => 'JavaScript gairė (tag)',
	'Installation_JsTagArchivingHelp' => 'Vidutinio ir aukšto lankytojų srauto svetainėms, rekomenduojame pasidomėti <a target="_blank" href="http://piwik.org/docs/setup-auto-archiving/">Kaip sukurti automatiškai archyvuojantį puslapį</a> ir priversti Piwik veikti dar greičiau!',
	'Installation_Congratulations' => 'Sveikiname',
	'Installation_CongratulationsHelp' => '<p>Sveikiname! Piwik diegimas baigtas.</p><p>Įsitikinkite, kad JavaScript žymė (tag) yra įrašyta visuose puslapiuose ir laukite pirmųjų lankytojų!</p>',
	'Installation_ContinueToPiwik' => 'Grįžti į Piwik',
	'Installation_SetupWebsite' => 'Svetainės nustatymai',
	'Installation_SetupWebSiteName' => 'svetainės pavadinimas',
	'Installation_SetupWebSiteURL' => 'svetainės URL',
	'Installation_Timezone' => 'svetainės laiko juosta',
	'Installation_SetupWebsiteError' => 'Rasta klaidų pridedant svetainę',
	'Installation_SetupWebsiteSetupSuccess' => 'Svetainė %s sukurta sėkmingai!',
	'Installation_SuperUser' => 'Super naudotojas',
	'Installation_SuperUserSetupSuccess' => 'Super naudotojas sukurtas sėkmingai!',
	'Installation_SuperUserLogin' => 'super naudotojo registracijos vardas',
	'Installation_Password' => 'slaptažodis',
	'Installation_PasswordRepeat' => 'pakartoti slaptažodį',
	'Installation_Email' => 'el. paštas',
	'Installation_SecurityNewsletter' => 'pranešti man apie svarbesnius Piwik atnaujinimus bei saugos įspėjimus',
	'Installation_CommunityNewsletter' => 'pranešti man apie bendruomenės atnaujinimus (naujus papildinius, naujas savybes ir pan.)',
	'Installation_PasswordDoNotMatch' => 'slaptažodis nesutampa',
	'Installation_Requirements' => 'Piwik reikalavimai sistemai',
	'Installation_Optional' => 'Pasirenkama',
	'Installation_Legend' => 'Sutartinis ženklas',
	'Installation_Extension' => 'plėtinys',
	'Installation_SystemCheck' => 'Sistemos patikra',
	'Installation_SystemCheckPhp' => 'PHP versija',
	'Installation_SystemCheckExtensions' => 'Kiti reikalingi plėtiniai',
	'Installation_SystemCheckDatabaseHelp' => 'Piwik reikalingas mysqli plėtinys arba abu PDO ir pdo_mysql plėtiniai',
	'Installation_SystemCheckPdoAndMysqliHelp' => 'Linux serveryje galite sukompiliuoti php su šiais nustatymais: %1$s į Jūsų php.ini failą įterpkite šias eilutes: %2$s',
	'Installation_SystemCheckPhpPdoAndMysqliSite' => 'Daugiau informacijos: <a style="color:red" href="http://php.net/pdo">PHP PDO</a> and <a style="color:red" href="http://php.net/mysqli">MYSQLI</a>.',
	'Installation_SystemCheckWinPdoAndMysqliHelp' => 'Windows serveryje galite įterpti šias eilutes į Jūsų php.ini failą: %s',
	'Installation_SystemCheckSplHelp' => 'Jums reikia sukonfigūruoti ir perdaryti PHP su įjungtu Standard PHP Library (SPL) (pagal nutylėjimą).',
	'Installation_SystemCheckZlibHelp' => 'Jums reikia sukonfigūruoti ir perdaryti PHP su įjungta "zlib" funkcija, --with-zlib.',
	'Installation_SystemCheckIconvHelp' => 'Jums reikia sukonfigūruoti ir perdaryti PHP su įjungtu "iconv" palaikymu, --with-iconv.',
	'Installation_SystemCheckWriteDirs' => 'Katalogai su rašymo teisėmis',
	'Installation_SystemCheckWriteDirsHelp' => 'Šios klaidos pataisymui Linux sistemoje, išbandykite šią komandą (-as)',
	'Installation_SystemCheckMemoryLimit' => 'Atminties limitas',
	'Installation_SystemCheckMemoryLimitHelp' => 'Didelio lankytojų srauto svetainėse archyvavimas gali reikalauti daugiau atminties nei šiuo metu yra.<br />Pasitikrinkite reikšmę memory_limit savo php.ini faile, jeigu būtina.',
	'Installation_SystemCheckOpenURL' => 'Open URL',
	'Installation_SystemCheckOpenURLHelp' => 'Naujienlaiškių prenumeratos, atnaujinimų pranešimai ir "vieno spustelėjimo" naujinimai reikalauja "curl" plėtinio, allow_url_fopen=On, arba aktyvuoto fsockopen()',
	'Installation_SystemCheckGD' => 'GD > 2.x (grafika)',
	'Installation_SystemCheckGDHelp' => 'Mažos diagramos neveiks.',
	'Installation_SystemCheckFunctions' => 'Reikalingos funkcijos',
	'Installation_SystemCheckOtherFunctions' => 'Kitos funkcijos',
	'Installation_SystemCheckTimeLimitHelp' => 'Didelio lankytojų srauto svetainėse archyvavimo proceso aktyvavimas gali reikalauti daugiau laiko nei šiuo metu leidžiama.<br />Pasitikrinkite reikšmę max_execution_time savo php.ini faile, jeigu būtina.',
	'Installation_SystemCheckMailHelp' => 'Atsiliepimų ir prarastų slpatažodžių pranešimai nebus siunčiami be mail() funkcijos.',
	'Installation_SystemCheckParseIniFileHelp' => 'Ši integruota funkcija yra išjungta Jūsų serveryje. Piwik pabandys emuliuoti šią funkciją, tačiau galimi saugumo suvaržymai ateityje. Stebėjimo sparta taip pat gali būti paveikta.',
	'Installation_SystemCheckEvalHelp' => 'Reikalinga HTML QuickForm ir Smarty šablonų sistema.',
	'Installation_SystemCheckMbstring' => 'mbstring',
	'Installation_SystemCheckMbstringExtensionHelp' => 'Mbstring plėtinys reikalingas daugiabitiniams simboliams API užklausose naudojant kableliu atskirtas reikšmes (CSV) arba tarpais atskirtas reikšmes (TSV)',
	'Installation_SystemCheckMbstringFuncOverloadHelp' => 'Turite nustatyti mbstring.func_overload į "0".',
	'Installation_SystemCheckFileIntegrity' => 'Failo vientisumas',
	'Installation_SystemCheckAutoUpdateHelp' => 'Pastaba: Piwik atnaujinimas "vienu paspaudimu" reikalauja rašymo teisių Piwik katalogui ir jo turiniui.',
	'Installation_SystemCheckError' => 'Rasta klaida turi būti ištaisyta prieš tęsiant',
	'Installation_SystemCheckWarning' => 'Piwik funkcionuos normaliai, tačiau kai kurios savybės gali būti prarastos',
	'Installation_SystemCheckSecureProtocol' => 'Saugus protokolas',
	'Installation_Tables' => 'Kuriamos lentelės',
	'Installation_TablesWithSameNamesFound' => 'Kai kurios %1$s lentelės Jūsų duombazėje %2$s pavadintos taip pat, kaip lentelės, kurias Piwik bando sukurti',
	'Installation_TablesFound' => 'Šios lentelės buvo rastos duombazėje',
	'Installation_TablesWarningHelp' => 'Pasirinkite ar naudoti jau esančias duombazėje lenteles, ar atlikti švarų įdiegimą ištrinant visus duomenis Piwik duombazėje.',
	'Installation_TablesReuse' => 'Naudoti esamas lenteles',
	'Installation_TablesDelete' => 'Ištrinti visas aptiktas lenteles',
	'Installation_TablesDeletedSuccess' => 'Esamos Piwik lentelės ištrintos sėkmingai',
	'Installation_TablesCreatedSuccess' => 'Lentelės sukurtos sėkmingai!',
	'Installation_DatabaseCreatedSuccess' => 'Duombazė %s sukurta sėkmingai!',
	'Installation_GoBackAndDefinePrefix' => 'Grįžkite atgal ir nurodykite Piwik lentelių priešdėlį',
	'Installation_ConfirmDeleteExistingTables' => 'Ar tikrai norite ištrinti lenteles: %s duombazėje? ĮSPĖJIMAS: ŠIŲ LENTELIŲ DUOMENYS TAPS NEATKURIAMAIS!',
	'Installation_Welcome' => 'Sveiki!',
	'Installation_WelcomeHelp' => '<p>Piwik yra atvirojo kodo programa, kuri leidžia lengvai rinkti informaciją apie Jūsų lankytojus.</p><p>Šis procesas padalintas į %s lengvus žingsnius, kurie užims apie 5 minutes.</p>',
	'Installation_ConfigurationHelp' => 'Jūsų Piwik konfigūracijos failas sukonfigūruotas netinkamai. Jūs galite ištrinti config/config.ini.php failą arba pakartoti diegimą, arba pakoreguoti susijungimo su duomenų baze nustatymus.',
	'Installation_ErrorInvalidState' => 'Klaida: Panašu, kad bandote praleisti įdiegimo procesą, arba Jūsų naršyklėje išjungti slapukai, arba Piwik konfigūracinis failas jau yra sukurtas. %1$sĮsitikinkite, kad slapukai įjungti%2$s ir grįžkite %3$s į pradinį įdiegimo puslapį %4$s.',
	'LanguagesManager_PluginDescription' => 'Šis papildinys pateikia visų prieinamų kalbų Piwik vartotojo sąsajai sąrašą. Kiekvienas naudotojas gali pasirinkti savo kalbą.',
	'LanguagesManager_AboutPiwikTranslations' => 'Apie Piwik vertimus',
	'Live_PluginDescription' => 'Sekite savo lankytojus gyvai, realiu laiku!',
	'Live_LinkVisitorLog' => 'Peržiūrėti išsamų apsilankymų žurnalą',
	'Live_Actions' => 'Veiksmai',
	'Live_Action' => 'Veiksmas',
	'Live_VisitorsInRealTime' => 'Lankytojai realiuoju laiku',
	'Live_VisitorLog' => 'Apsilankymų žurnalas',
	'Live_Time' => 'Laikas',
	'Live_Referrer_URL' => 'Persiunčiančiojo URL',
	'Live_LastMinutes' => 'Paskutinės %s minutės',
	'Live_LastHours' => 'Paskutinės %s valandos',
	'Live_GoalType' => 'Tipas',
	'Live_GoalTime' => '1-os konversijos laikas',
	'Live_KeywordRankedOnSearchResultForThisVisitor' => 'Šiam lankytojui raktažodis %1$s buvo parodytas %2$s %3$s paieškos rezultatuose',
	'Live_GoalRevenue' => 'Pajamos',
	'Live_GoalDetails' => 'Išsamiau',
	'Login_PluginDescription' => 'Prisijungimo autentifikacijos papildinys, nuskaitantis prisijungimo informaciją iš config/config.inc.php failo Super User\'iui, ir iš duomenų bazės kitiems naudotojams. Galima lengvai pakeisti kitais autentifikacijos mechanizmais (OpenID, htaccess, custom Auth ir t.t.)',
	'Login_LoginPasswordNotCorrect' => 'Naudotojo vardas ir slaptažodis neteisingi',
	'Login_Password' => 'Slaptažodis',
	'Login_PasswordRepeat' => 'Slaptažodis (pakartoti)',
	'Login_ChangePassword' => 'Pakeisti slaptažodį',
	'Login_LoginOrEmail' => 'Registracijos vardas arba el. paštas',
	'Login_RememberMe' => 'Prisiminti mane',
	'Login_LogIn' => 'Prisijungti',
	'Login_Logout' => 'Atsijungti',
	'Login_LostYourPassword' => 'Pamiršote slaptažodį?',
	'Login_RemindPassword' => 'Priminti slaptažodį',
	'Login_PasswordResetToken' => 'Slaptažodžio keitimo talonas',
	'Login_PasswordReminder' => 'Prašome įvesti naudotojo vardą arba el. pašto adresą. Naują slaptažodį gausite el. paštu.',
	'Login_PasswordsDoNotMatch' => 'Slaptažodžiai nesutampa',
	'Login_PasswordSuccessfullyChanged' => 'Slaptažodis pakeistas sėkmingai!',
	'Login_InvalidUsernameEmail' => 'Netinkamas naudotojo vardas ir/arba el. pašto adresas',
	'Login_InvalidOrExpiredToken' => 'Netinkamas arba pasibaigęs talonas',
	'Login_MailTopicPasswordRecovery' => 'Slaptažodžio atkūrimas',
	'Login_MailPasswordRecoveryBody' => 'Sveiki, %1$s, Iš %2$s buvo gautas slaptažodžio nustatymo iš naujo prašymas. Slaptažodžio nustatymui iš naujo: 1) Eikite į slaptažodžio nustatymo formą: %3$s 2) Įveskite šią žymą: %4$s 3) Užpildykite formą (dukart pakartojant slaptažodį) ir išsiųskite. Pastaba: ši žymas nustos galioti po 24 val.',
	'Login_PasswordSent' => 'Slaptažodis nusiųstas. Pasitikrinkite el. paštą.',
	'Login_ContactAdmin' => 'Galima priežastis: Jūsų pagr. kompiuteryje (serveryje) gali būti išjungta mail() funkcija.<br />Prašome susisiekti su savo Piwik administratoriumi.',
	'Login_ExceptionInvalidSuperUserAuthenticationMethod' => 'Super naudojas negali būti patikrintas naudojantis \'%s\' mechanizmu.',
	'MultiSites_Evolution' => 'Raida',
	'Provider_PluginDescription' => 'Nurodo lankytojų interneto paslaugų tiekėją.',
	'Provider_WidgetProviders' => 'IP tiekėjai',
	'Provider_ColumnProvider' => 'IP tiekėjas',
	'Provider_SubmenuLocationsProvider' => 'Vietovės ir IP tiekėjas',
	'Referers_PluginDescription' => 'Nurodo šaltinio duomenis: paieškos variklius, raktinius žodžius, svetaines, tiesioginius apsilankymus ir t.t.',
	'Referers_Referers' => 'Šaltiniai',
	'Referers_SearchEngines' => 'Paieškos sistemos',
	'Referers_Keywords' => 'Raktiniai žodžiai',
	'Referers_DirectEntry' => 'Tiesioginis apsilankymas',
	'Referers_Websites' => 'Svetainės',
	'Referers_Campaigns' => 'Kampanijos',
	'Referers_Evolution' => 'Raida periodu',
	'Referers_Type' => 'Šaltinio tipas',
	'Referers_ColumnRefererType' => 'Šaltinio tipas',
	'Referers_ColumnSearchEngine' => 'Paieškos sistema',
	'Referers_ColumnWebsite' => 'Svetainė',
	'Referers_ColumnWebsitePage' => 'Svetainės puslapis',
	'Referers_ColumnKeyword' => 'Raktinis žodis',
	'Referers_ColumnCampaign' => 'Kampanija',
	'Referers_RefererName' => 'Šaltinio pavadinimas',
	'Referers_DetailsByRefererType' => 'Duomenys pagal šaltinio tipą',
	'Referers_TypeDirectEntries' => '%s tiesioginiai apsilankymai',
	'Referers_TypeSearchEngines' => '%s per paieškos sistemas',
	'Referers_TypeWebsites' => '%s iš svetainių',
	'Referers_TypeCampaigns' => '%s per kampanijas',
	'Referers_Distinct' => 'Atskirti šaltinius pagal tipą',
	'Referers_DistinctSearchEngines' => 'atskirti paieškos sistemas',
	'Referers_DistinctKeywords' => 'atskirti raktinius žodžius',
	'Referers_DistinctCampaigns' => 'atskirti kampanijas',
	'Referers_DistinctWebsites' => 'atskirti svetaines',
	'Referers_UsingNDistinctUrls' => '(naudojant %s skirtingus URL)',
	'Referers_SubmenuOverview' => 'Apžvalga',
	'Referers_SubmenuSearchEngines' => 'Paieškos sistemos ir raktiniai žodžiai',
	'Referers_SubmenuWebsites' => 'Svetainės',
	'Referers_SubmenuCampaigns' => 'Kampanijos',
	'Referers_WidgetKeywords' => 'Raktinių žodžių sąrašas',
	'Referers_WidgetCampaigns' => 'Kampanijų sąrašas',
	'Referers_WidgetExternalWebsites' => 'Išorinių svetainių sąrašas',
	'Referers_WidgetSearchEngines' => 'Geriausios paieškos sistemos',
	'Referers_WidgetOverview' => 'Bendras vaizdas',
	'SecurityInfo_PluginDescription' => 'Sukurtas pagal PhpSecInfo iš PHP Saugumo Konsorciumo, šis papildinys pateikia saugumo informaciją apie Jūsų PHP aplinką bei pateikia pasiūlymus kaip ją pagerinti.',
	'SecurityInfo_Security' => 'Saugumas',
	'SecurityInfo_SecurityInformation' => 'PHP saugumo informacija',
	'SecurityInfo_Test' => 'Testas',
	'SecurityInfo_Result' => 'Rezultatas',
	'SEO_SeoRankings' => 'SEO reitingai',
	'SEO_AlexaRank' => 'Alexa reitingas',
	'SEO_DomainAge' => 'Adresų srities amžius',
	'SEO_Rank' => 'Reitingas',
	'SEO_Backlinks' => 'Nuorodos į svetainę',
	'SEO_Pages' => 'Puslapiai',
	'SEO_SEORankingsFor' => 'SEO reitingai skirti %s',
	'SitesManager_PluginDescription' => 'Svetainių administravimas: Pridėkite naujas svetaines, redaguokite esamas, gaukite Javascript kodą įkėlimui į savo svetainę. Visi šie veiksmai taip pat pasiekiami per API sąsają.',
	'SitesManager_Sites' => 'Svetainės',
	'SitesManager_TrackingTags' => 'Sekimo žymės skirtos %s',
	'SitesManager_WebsitesManagement' => 'Svetainių valdymas',
	'SitesManager_MainDescription' => 'Pridėkite, atnaujinkite, šalinkite svetaines ir gaukite JavaScript kodą.',
	'SitesManager_JsTrackingTag' => 'JavaScript Sekimo gairė (Tracking Tag)',
	'SitesManager_JsTrackingTagHelp' => 'JavaScript Sekimo gairė (Tracking tag) skirta įterpti visuose Jūsų puslapiuose',
	'SitesManager_ShowTrackingTag' => 'parodyti sekimo gairę (tracking tag)',
	'SitesManager_NoWebsites' => 'Neturite jokių svetainių administravimui.',
	'SitesManager_AddSite' => 'Pridėti naują svetainę',
	'SitesManager_NotFound' => 'Nerasta svetainių',
	'SitesManager_AliasUrlHelp' => 'Rekomenduojama, nors ir nebūtina, nurodyti įvarius URLs, kuriais lankytojai pasiekia šią svetainę. Alternatyvių vardų URLs svetainei nebus atvaizduojama Šaltiniai > Svetainių ataskaitos. Nebūtina nurodyti URL su ar be \'www\', kadangi Piwik automatiškai palaiko abu.',
	'SitesManager_Urls' => 'Adresai (URLs)',
	'SitesManager_MenuSites' => 'Svetainės',
	'SitesManager_DeleteConfirm_js' => 'Ar tikrai norite pašalinti svetainę %s?',
	'SitesManager_ExceptionDeleteSite' => 'Neįmanoma pašalinti svetainės, nes tai yra vienintelė registruota svetainė. Pirmiausia pridėkite naują svetainę, o vėliau ištrinkite šią.',
	'SitesManager_ExceptionNoUrl' => 'Turite nurodyti bent vieną adresą (URL) svetainei.',
	'SitesManager_ExceptionEmptyName' => 'Svetainės pavadinimas negali būti tuščias.',
	'SitesManager_ExceptionInvalidUrl' => 'Adresas (URL) \'%s\' netinkamas.',
	'SitesManager_ExceptionInvalidTimezone' => '"%s" laiko juosta nurodyta neteisingai. Prašome nurodyti laiko juostą teisingai.',
	'SitesManager_ExceptionInvalidCurrency' => '"%s" valiuta nurodyta neteisingai. prašome teisingai nurodyti valiutą (pvz. %s)',
	'SitesManager_ExceptionInvalidIPFormat' => 'Išimtinis IP "%s" nurodytas netinkamu IP formatu (pvz.. %s).',
	'SitesManager_SuperUserCan' => 'Super naudotojas taip pat gali %s nustatyti globalias parinktis%s naujoms svetainėms.',
	'SitesManager_ExcludedIps' => 'Išimtiniai IP',
	'SitesManager_GlobalListExcludedIps' => 'Globalus išimtinių IP sąrašas',
	'SitesManager_ListOfIpsToBeExcludedOnAllWebsites' => 'Žemiau nurodyti IP adresai nebus stebimi visose svetainėse.',
	'SitesManager_ExcludedParameters' => 'Išimtinių parametrai',
	'SitesManager_GlobalListExcludedQueryParameters' => 'Globalus sąrašas užklausų URL parametrų skirtų neįtraukti',
	'SitesManager_ListOfQueryParametersToBeExcludedOnAllWebsites' => 'Užklausų URL parametrai nurodyti žemiau nebus įtraukiami į URL visose svetainėse.',
	'SitesManager_ListOfQueryParametersToExclude' => 'Įveskite URL užklausų parametrų sąrašą, vienas eilutėje.',
	'SitesManager_PiwikWillAutomaticallyExcludeCommonSessionParameters' => 'Piwik automatiškai neįtrauks paplitusių sesijos parametrų (%s).',
	'SitesManager_HelpExcludedIps' => 'Įveskite IP sąrašą, vienas eilutėje, kurio nenorite sekti. Galite naudoti pakaitos simbolius, pvz. %1$s ar %2$s',
	'SitesManager_YourCurrentIpAddressIs' => 'Jūsų dabartinis IP adresas yra %s',
	'SitesManager_SelectACity' => 'Pasirinkite miestą',
	'SitesManager_ChooseCityInSameTimezoneAsYou' => 'Pasirinkite miestą toje pačioje laiko juostoje kaip ir Jūs.',
	'SitesManager_ChangingYourTimezoneWillOnlyAffectDataForward' => 'Laiko juostos pakeitimas įtakos tik vėlesnius duomenis ir neįtakos ankstesnių.',
	'SitesManager_AdvancedTimezoneSupportNotFound' => 'Išplėstas laiko juostų palaikymas nerastas Jūsų PHP (palaikoma nuo PHP>=5.2). Jūs vis tiek galite pasirinkti rankinį UTC padengimą.',
	'SitesManager_UTCTimeIs' => 'UTC laikas yra %s.',
	'SitesManager_Timezone' => 'Laiko juosta',
	'SitesManager_GlobalWebsitesSettings' => 'Globalūs svetainių nustatymai',
	'SitesManager_DefaultTimezoneForNewWebsites' => 'Numatytoji laiko juosta naujoms svetainėms',
	'SitesManager_SelectDefaultTimezone' => 'Galite pasirinkti numatytąją laiko juostą naujoms svetainėms.',
	'SitesManager_Currency' => 'Valiuta',
	'SitesManager_CurrencySymbolWillBeUsedForGoals' => 'Valiutos simbolis bus rodomas šalia uždavinių pajamų.',
	'SitesManager_DefaultCurrencyForNewWebsites' => 'Numatytoji valiuta naujoms svetainėms',
	'SitesManager_SelectDefaultCurrency' => 'Galite pasirinkti numatytąją valiutą naujoms svetainėms.',
	'SitesManager_EnableEcommerce' => 'Komercinė svetainė',
	'SitesManager_NotAnEcommerceSite' => 'Nekomercinė svetainė',
	'TranslationsAdmin_PluginDescription' => 'Padėkite versti Piwik į Jūsų kalbą.',
	'TranslationsAdmin_MenuTranslations' => 'Vertimai',
	'TranslationsAdmin_MenuLanguages' => 'Kalbos',
	'TranslationsAdmin_LanguageCode' => 'Kalbos kodas',
	'TranslationsAdmin_Plugin' => 'Papildinys',
	'TranslationsAdmin_Definition' => 'Apibrėžimas',
	'TranslationsAdmin_DefaultString' => 'Numatytoji reikšmė (English)',
	'TranslationsAdmin_TranslationString' => 'Vertimas (dabartinė kalba: %s)',
	'TranslationsAdmin_Translations' => 'Vertimai',
	'TranslationsAdmin_FixPermissions' => 'Prašome susitvarkyti failų sistemos leidimus',
	'TranslationsAdmin_AddLanguage' => 'Pridėti kalbą',
	'TranslationsAdmin_Export' => 'Eksportuoti kalbą',
	'TranslationsAdmin_Import' => 'Importuoti kalbą',
	'UserCountry_PluginDescription' => 'Nurodo lankytojų šalis.',
	'UserCountry_Country' => 'Šalis',
	'UserCountry_Continent' => 'Kontinentas',
	'UserCountry_DistinctCountries' => '%s atskirti šalis',
	'UserCountry_Location' => 'Vietovė',
	'UserCountry_SubmenuLocations' => 'Vietovės',
	'UserCountry_WidgetContinents' => 'Lankytojų kontinentai',
	'UserCountry_WidgetCountries' => 'Lankytojų šalys',
	'UserCountry_country_ac' => 'Ascension Islands',
	'UserCountry_country_ad' => 'Andora',
	'UserCountry_country_ae' => 'Jungtiniai Arabų Emyratai',
	'UserCountry_country_af' => 'Afganistanas',
	'UserCountry_country_ag' => 'Antigua and Barbuda',
	'UserCountry_country_ai' => 'Anguilla',
	'UserCountry_country_al' => 'Albanija',
	'UserCountry_country_am' => 'Armenija',
	'UserCountry_country_an' => 'Netherlands Antilles',
	'UserCountry_country_ao' => 'Angola',
	'UserCountry_country_aq' => 'Antarctica',
	'UserCountry_country_ar' => 'Argentina',
	'UserCountry_country_as' => 'American Samoa',
	'UserCountry_country_at' => 'Austrija',
	'UserCountry_country_au' => 'Australija',
	'UserCountry_country_aw' => 'Aruba',
	'UserCountry_country_ax' => 'Aland Islands',
	'UserCountry_country_az' => 'Azerbaidžanas',
	'UserCountry_country_ba' => 'Bosnija ir Hercogovina',
	'UserCountry_country_bb' => 'Barbadosas',
	'UserCountry_country_bd' => 'Bangladešas',
	'UserCountry_country_be' => 'Belgija',
	'UserCountry_country_bf' => 'Burkina Faso',
	'UserCountry_country_bg' => 'Bulgarija',
	'UserCountry_country_bh' => 'Bahrain',
	'UserCountry_country_bi' => 'Burundis',
	'UserCountry_country_bj' => 'Benin',
	'UserCountry_country_bl' => 'Saint Barthelemy',
	'UserCountry_country_bm' => 'Bermudai',
	'UserCountry_country_bn' => 'Bruneo',
	'UserCountry_country_bo' => 'Bolivija',
	'UserCountry_country_br' => 'Brazilija',
	'UserCountry_country_bs' => 'Bahamai',
	'UserCountry_country_bt' => 'Butanas',
	'UserCountry_country_bu' => 'Burma',
	'UserCountry_country_bv' => 'Bouvet Island',
	'UserCountry_country_bw' => 'Botsvana',
	'UserCountry_country_by' => 'Baltarusij',
	'UserCountry_country_bz' => 'Belize',
	'UserCountry_country_ca' => 'Kanada',
	'UserCountry_country_cc' => 'Cocos (Keeling) Islands',
	'UserCountry_country_cd' => 'Kongo Demokratinė Respublika',
	'UserCountry_country_cf' => 'Central African Republic',
	'UserCountry_country_cg' => 'Kongas',
	'UserCountry_country_ch' => 'Šveicarija',
	'UserCountry_country_ci' => 'Cote D\'Ivoire',
	'UserCountry_country_ck' => 'Cook Islands',
	'UserCountry_country_cl' => 'Čilė',
	'UserCountry_country_cm' => 'Kamerūnas',
	'UserCountry_country_cn' => 'Kinija',
	'UserCountry_country_co' => 'Kolumbija',
	'UserCountry_country_cp' => 'Clipperton Island',
	'UserCountry_country_cr' => 'Kosta Rika',
	'UserCountry_country_cs' => 'Serbia Montenegro',
	'UserCountry_country_cu' => 'Kuba',
	'UserCountry_country_cv' => 'Cape Verde',
	'UserCountry_country_cw' => 'Curaçao',
	'UserCountry_country_cx' => 'Kalėdų sala',
	'UserCountry_country_cy' => 'Kipras',
	'UserCountry_country_cz' => 'Čekijos Respublika',
	'UserCountry_country_de' => 'Vokietija',
	'UserCountry_country_dg' => 'Diego Garcia',
	'UserCountry_country_dj' => 'Djibouti',
	'UserCountry_country_dk' => 'Danija',
	'UserCountry_country_dm' => 'Dominika',
	'UserCountry_country_do' => 'Dominican Republic',
	'UserCountry_country_dz' => 'Alžyras',
	'UserCountry_country_ea' => 'Ceuta, Melilla',
	'UserCountry_country_ec' => 'Ecuador',
	'UserCountry_country_ee' => 'Estija',
	'UserCountry_country_eg' => 'Egiptas',
	'UserCountry_country_eh' => 'Western Sahara',
	'UserCountry_country_er' => 'Eritrea',
	'UserCountry_country_es' => 'Ispanija',
	'UserCountry_country_et' => 'Etiopija',
	'UserCountry_country_eu' => 'Europos Sąjunga',
	'UserCountry_country_fi' => 'Suomija',
	'UserCountry_country_fj' => 'Fidžis',
	'UserCountry_country_fk' => 'Falkland Islands (Malvinas)',
	'UserCountry_country_fm' => 'Micronesia, Federated States of',
	'UserCountry_country_fo' => 'Faroe Islands',
	'UserCountry_country_fr' => 'Prancūzija',
	'UserCountry_country_fx' => 'France, Metropolitan',
	'UserCountry_country_ga' => 'Gabon',
	'UserCountry_country_gb' => 'Didžioji Britanija',
	'UserCountry_country_gd' => 'Grenada',
	'UserCountry_country_ge' => 'Gruzija',
	'UserCountry_country_gf' => 'French Guyana',
	'UserCountry_country_gg' => 'Guernsey',
	'UserCountry_country_gh' => 'Gana',
	'UserCountry_country_gi' => 'Gibraltaras',
	'UserCountry_country_gl' => 'Greenland',
	'UserCountry_country_gm' => 'Gambija',
	'UserCountry_country_gn' => 'Gvinėja',
	'UserCountry_country_gp' => 'Gvadelupė',
	'UserCountry_country_gq' => 'Equatorial Guinea',
	'UserCountry_country_gr' => 'Graikija',
	'UserCountry_country_gs' => 'South Georgia and the South Sandwich Islands',
	'UserCountry_country_gt' => 'Guatemala',
	'UserCountry_country_gu' => 'Guam',
	'UserCountry_country_gw' => 'Guinea-Bissau',
	'UserCountry_country_gy' => 'Guyana',
	'UserCountry_country_hk' => 'Hong Kong',
	'UserCountry_country_hm' => 'Heard Island and McDonald Islands',
	'UserCountry_country_hn' => 'Hondūras',
	'UserCountry_country_hr' => 'Kroatija',
	'UserCountry_country_ht' => 'Haitis',
	'UserCountry_country_hu' => 'Hungary',
	'UserCountry_country_ic' => 'Canary Islands',
	'UserCountry_country_id' => 'Indonezija',
	'UserCountry_country_ie' => 'Airija',
	'UserCountry_country_il' => 'Izraelis',
	'UserCountry_country_im' => 'Man Island',
	'UserCountry_country_in' => 'Indija',
	'UserCountry_country_io' => 'British Indian Ocean Territory',
	'UserCountry_country_iq' => 'Irakas',
	'UserCountry_country_ir' => 'Iran, Islamic Republic of',
	'UserCountry_country_is' => 'Islandija',
	'UserCountry_country_it' => 'Italija',
	'UserCountry_country_je' => 'Jersey',
	'UserCountry_country_jm' => 'Jamaika',
	'UserCountry_country_jo' => 'Jordanas',
	'UserCountry_country_jp' => 'Japonija',
	'UserCountry_country_ke' => 'Kenya',
	'UserCountry_country_kg' => 'Kyrgyzstan',
	'UserCountry_country_kh' => 'Cambodia',
	'UserCountry_country_ki' => 'Kiribati',
	'UserCountry_country_km' => 'Comoros',
	'UserCountry_country_kn' => 'Saint Kitts and Nevis',
	'UserCountry_country_kp' => 'Korea, Democratic People\'s Republic of',
	'UserCountry_country_kr' => 'Korea, Republic of',
	'UserCountry_country_kw' => 'Kuwait',
	'UserCountry_country_ky' => 'Cayman Islands',
	'UserCountry_country_kz' => 'Kazakhstan',
	'UserCountry_country_la' => 'Laos',
	'UserCountry_country_lb' => 'Lebanon',
	'UserCountry_country_lc' => 'Saint Lucia',
	'UserCountry_country_li' => 'Liechtenstein',
	'UserCountry_country_lk' => 'Sri Lanka',
	'UserCountry_country_lr' => 'Liberia',
	'UserCountry_country_ls' => 'Lesotho',
	'UserCountry_country_lt' => 'Lietuva',
	'UserCountry_country_lu' => 'Luxembourg',
	'UserCountry_country_lv' => 'Latvija',
	'UserCountry_country_ly' => 'Libya',
	'UserCountry_country_ma' => 'Morocco',
	'UserCountry_country_mc' => 'Monaco',
	'UserCountry_country_md' => 'Moldova, Republic of',
	'UserCountry_country_me' => 'Montenegro',
	'UserCountry_country_mf' => 'Saint Martin',
	'UserCountry_country_mg' => 'Madagascar',
	'UserCountry_country_mh' => 'Marshall Islands',
	'UserCountry_country_mk' => 'Macedonia',
	'UserCountry_country_ml' => 'Mali',
	'UserCountry_country_mm' => 'Myanmar',
	'UserCountry_country_mn' => 'Mongolia',
	'UserCountry_country_mo' => 'Macau',
	'UserCountry_country_mp' => 'Northern Mariana Islands',
	'UserCountry_country_mq' => 'Martinique',
	'UserCountry_country_mr' => 'Mauritania',
	'UserCountry_country_ms' => 'Montserrat',
	'UserCountry_country_mt' => 'Malta',
	'UserCountry_country_mu' => 'Mauritius',
	'UserCountry_country_mv' => 'Maldives',
	'UserCountry_country_mw' => 'Malawi',
	'UserCountry_country_mx' => 'Mexico',
	'UserCountry_country_my' => 'Malaysia',
	'UserCountry_country_mz' => 'Mozambique',
	'UserCountry_country_na' => 'Namibia',
	'UserCountry_country_nc' => 'New Caledonia',
	'UserCountry_country_ne' => 'Niger',
	'UserCountry_country_nf' => 'Norfolk Island',
	'UserCountry_country_ng' => 'Nigeria',
	'UserCountry_country_ni' => 'Nicaragua',
	'UserCountry_country_nl' => 'Netherlands',
	'UserCountry_country_no' => 'Norway',
	'UserCountry_country_np' => 'Nepal',
	'UserCountry_country_nr' => 'Nauru',
	'UserCountry_country_nt' => 'Neutral Zone',
	'UserCountry_country_nu' => 'Niue',
	'UserCountry_country_nz' => 'New Zealand',
	'UserCountry_country_om' => 'Oman',
	'UserCountry_country_pa' => 'Panama',
	'UserCountry_country_pe' => 'Peru',
	'UserCountry_country_pf' => 'French Polynesia',
	'UserCountry_country_pg' => 'Papua New Guinea',
	'UserCountry_country_ph' => 'Philippines',
	'UserCountry_country_pk' => 'Pakistan',
	'UserCountry_country_pl' => 'Lenkija',
	'UserCountry_country_pm' => 'Saint Pierre and Miquelon',
	'UserCountry_country_pn' => 'Pitcairn',
	'UserCountry_country_pr' => 'Puerto Rico',
	'UserCountry_country_ps' => 'Palestinian Territory',
	'UserCountry_country_pt' => 'Portugal',
	'UserCountry_country_pw' => 'Palau',
	'UserCountry_country_py' => 'Paraguay',
	'UserCountry_country_qa' => 'Qatar',
	'UserCountry_country_re' => 'Reunion Island',
	'UserCountry_country_ro' => 'Romania',
	'UserCountry_country_rs' => 'Serbia',
	'UserCountry_country_ru' => 'Rusija',
	'UserCountry_country_rw' => 'Rwanda',
	'UserCountry_country_sa' => 'Saudi Arabia',
	'UserCountry_country_sb' => 'Solomon Islands',
	'UserCountry_country_sc' => 'Seychelles',
	'UserCountry_country_sd' => 'Sudan',
	'UserCountry_country_se' => 'Sweden',
	'UserCountry_country_sf' => 'Finland',
	'UserCountry_country_sg' => 'Singapore',
	'UserCountry_country_sh' => 'Saint Helena',
	'UserCountry_country_si' => 'Slovenia',
	'UserCountry_country_sj' => 'Svalbard',
	'UserCountry_country_sk' => 'Slovakia',
	'UserCountry_country_sl' => 'Sierra Leone',
	'UserCountry_country_sm' => 'San Marino',
	'UserCountry_country_sn' => 'Senegal',
	'UserCountry_country_so' => 'Somalia',
	'UserCountry_country_sr' => 'Suriname',
	'UserCountry_country_st' => 'Sao Tome and Principe',
	'UserCountry_country_su' => 'Old U.S.S.R',
	'UserCountry_country_sv' => 'El Salvador',
	'UserCountry_country_sy' => 'Syrian Arab Republic',
	'UserCountry_country_sz' => 'Swaziland',
	'UserCountry_country_ta' => 'Tristan da Cunha',
	'UserCountry_country_tc' => 'Turks and Caicos Islands',
	'UserCountry_country_td' => 'Chad',
	'UserCountry_country_tf' => 'French Southern Territories',
	'UserCountry_country_tg' => 'Togo',
	'UserCountry_country_th' => 'Thailand',
	'UserCountry_country_tj' => 'Tajikistan',
	'UserCountry_country_tk' => 'Tokelau',
	'UserCountry_country_tl' => 'East Timor',
	'UserCountry_country_tm' => 'Turkmenistan',
	'UserCountry_country_tn' => 'Tunisia',
	'UserCountry_country_to' => 'Tonga',
	'UserCountry_country_tp' => 'East Timor',
	'UserCountry_country_tr' => 'Turkey',
	'UserCountry_country_tt' => 'Trinidad and Tobago',
	'UserCountry_country_tv' => 'Tuvalu',
	'UserCountry_country_tw' => 'Taiwan',
	'UserCountry_country_tz' => 'Tanzania, United Republic of',
	'UserCountry_country_ua' => 'Ukraine',
	'UserCountry_country_ug' => 'Uganda',
	'UserCountry_country_uk' => 'Jungtinė Karalystė',
	'UserCountry_country_um' => 'United States Minor Outlying Islands',
	'UserCountry_country_us' => 'Jungtinės Valstijos',
	'UserCountry_country_uy' => 'Uruguay',
	'UserCountry_country_uz' => 'Uzbekistan',
	'UserCountry_country_va' => 'Vatican City',
	'UserCountry_country_vc' => 'Saint Vincent and the Grenadines',
	'UserCountry_country_ve' => 'Venezuela',
	'UserCountry_country_vg' => 'Virgin Islands, British',
	'UserCountry_country_vi' => 'Virgin Islands, U.S.',
	'UserCountry_country_vn' => 'Vietnam',
	'UserCountry_country_vu' => 'Vanuatu',
	'UserCountry_country_wf' => 'Wallis and Futuna',
	'UserCountry_country_ws' => 'Samoa',
	'UserCountry_country_ye' => 'Yemen',
	'UserCountry_country_yt' => 'Mayotte',
	'UserCountry_country_yu' => 'Yugoslavia',
	'UserCountry_country_za' => 'South Africa',
	'UserCountry_country_zm' => 'Zambia',
	'UserCountry_country_zr' => 'Zaire',
	'UserCountry_country_zw' => 'Zimbabwe',
	'UserCountry_country_a1' => 'Anonimas (proxy)',
	'UserCountry_country_a2' => 'Palydovinis tiekėjas',
	'UserCountry_country_ap' => 'Azijos / Ramiojo vandenyno regionas',
	'UserCountry_country_o1' => 'Kita šalis',
	'UserCountry_country_cat' => 'Kataloniškai kalbančios bendruomenės',
	'UserCountry_continent_eur' => 'Europa',
	'UserCountry_continent_afr' => 'Afrika',
	'UserCountry_continent_ant' => 'Antarktida',
	'UserCountry_continent_asi' => 'Azija',
	'UserCountry_continent_amn' => 'Šiaurės Amerika',
	'UserCountry_continent_amc' => 'Centrinė Amerika',
	'UserCountry_continent_ams' => 'Pietų ir Centrinė Amerika',
	'UserCountry_continent_oce' => 'Okeanija',
	'UserCountryMap_map' => 'žemėlapis',
	'UserCountryMap_worldMap' => 'pasaulio žamėlapis',
	'UserCountryMap_toggleFullscreen' => 'Perjungti į visą ekraną',
	'UserSettings_PluginDescription' => 'Parodo įvairius lankytojo nustatymus: naršyklę, naršyklės šeimą, operacinę sistemą, papildinius, ekrano raišką, skiriamąją gebą, globalius nustatymus.',
	'UserSettings_VisitorSettings' => 'Lankytojų nustatymai',
	'UserSettings_BrowserFamilies' => 'Naršyklių šeimos',
	'UserSettings_Browsers' => 'Naršyklės',
	'UserSettings_Plugins' => 'Papildiniai',
	'UserSettings_Configurations' => 'Konfigūracijos',
	'UserSettings_OperatingSystems' => 'Operacinės sistemos',
	'UserSettings_Resolutions' => 'Ekranų raiškos',
	'UserSettings_WideScreen' => 'Plačiaekranis',
	'UserSettings_ColumnBrowserFamily' => 'Naršyklių šeimos',
	'UserSettings_ColumnBrowser' => 'Naršyklė',
	'UserSettings_ColumnBrowserVersion' => 'Naršyklės versija',
	'UserSettings_ColumnPlugin' => 'Papildinys',
	'UserSettings_ColumnConfiguration' => 'Konfigūracija',
	'UserSettings_ColumnOperatingSystem' => 'Operacinė sistema',
	'UserSettings_ColumnResolution' => 'Ekrano raiška',
	'UserSettings_ColumnTypeOfScreen' => 'Ekrano tipas',
	'UserSettings_WidgetResolutions' => 'Ekrano raiška',
	'UserSettings_WidgetBrowsers' => 'Lankytojų naršyklės',
	'UserSettings_WidgetPlugins' => 'Papildinių sąrašas',
	'UserSettings_PluginDetectionDoesNotWorkInIE' => 'Pastaba: papildinio aptikimas neveikia Internet Explorer naršyklėje. Ši ataskaita bus sugeneruota tik kitose naršyklėse.',
	'UserSettings_WidgetWidescreen' => 'Normalus / Plačiaekranis',
	'UserSettings_WidgetBrowserFamilies' => 'Naršyklės pagal šeimą',
	'UserSettings_WidgetOperatingSystems' => 'Operacinės sistemos',
	'UserSettings_WidgetGlobalVisitors' => 'Bendri lankytojų nustatymai',
	'UserSettings_SubmenuSettings' => 'Nustatymai',
	'UsersManager_PluginDescription' => 'Piwik naudotojų administravimas: pridėkite naudotoją, redaguokite esamą, atnaujinkite leidimus. Visi veiksmai taip pat pasiekiami per API sąsają.',
	'UsersManager_UsersManagement' => 'Naudotojų valdymas',
	'UsersManager_UsersManagementMainDescription' => 'Kurkite naujus naudotojus arba keiskite jau esančius. Po to aukščiau galite parinkti jiems leidimus.',
	'UsersManager_ManageAccess' => 'Administruoti teises',
	'UsersManager_MainDescription' => 'Nuspręskite kuris naudotojas kokias Piwik teises turės Jūsų svetainei. Taip pat galite sukurti leidimus visoms svetainėms iš karto.',
	'UsersManager_Sites' => 'Svetainės',
	'UsersManager_AllWebsites' => 'Visos svetainės',
	'UsersManager_ApplyToAllWebsites' => 'Taikyti visoms svetainėms',
	'UsersManager_User' => 'Naudotojas',
	'UsersManager_PrivNone' => 'Neleidžiama',
	'UsersManager_PrivView' => 'Matyti',
	'UsersManager_PrivAdmin' => 'Administruoti',
	'UsersManager_ChangeAllConfirm' => 'Ar tikrai norite pakeisti \'%s\' leidimus visoms svetainėms?',
	'UsersManager_Password' => 'Slaptažodis',
	'UsersManager_Email' => 'El. paštas',
	'UsersManager_Alias' => 'Alternatyvus vardas',
	'UsersManager_TheSuperUserAliasCannotBeChanged' => 'Alternatyvus super naudotojo vardas negali būti pakeistas.',
	'UsersManager_ExcludeVisitsViaCookie' => 'Neįtraukite savo apsilankymų pasinaudoję slapuku',
	'UsersManager_YourVisitsAreIgnoredOnDomain' => '%sJūsų apsilankymai yra ignoruojami Piwik %s %s (Piwik ignoravimo slapukas buvo aptiktas Jūsų naršyklėje).',
	'UsersManager_ClickHereToDeleteTheCookie' => 'Spauskite čia, kad ištrintumėte slapuką ir Piwik stebėtų Jūsų apsilankymus',
	'UsersManager_ClickHereToSetTheCookieOnDomain' => 'Spauskite čia, kad sukurtumėte slapuką, kuris neleis Piwik sekti Jūsų apsilankymų %s',
	'UsersManager_Edit' => 'Redaguoti',
	'UsersManager_AddUser' => 'Pridėti naują naudotoją',
	'UsersManager_MenuUsers' => 'Naudotojai',
	'UsersManager_MenuUserSettings' => 'Naudotojo nustatymai',
	'UsersManager_MenuAnonymousUserSettings' => 'Anonimo nustatymai',
	'UsersManager_NoteNoAnonymousUserAccessSettingsWontBeUsed' => 'Pastaba: Jūs neturite jokių svetainių, kurias gali pasiekti anonimas, todėl šie nustatymai nebus naudojami.',
	'UsersManager_WhenUsersAreNotLoggedInAndVisitPiwikTheyShouldAccess' => 'Kai naudotojai neprisijungę apsilanko Piwik, jie turi pasiekti',
	'UsersManager_ChangePassword' => 'Pakeisti slaptažodį',
	'UsersManager_IfYouWouldLikeToChangeThePasswordTypeANewOne' => 'Jei norite pakeisti slaptažodį, įrašykite naują. Jei ne, palikite laukelį tuščią.',
	'UsersManager_TypeYourPasswordAgain' => 'Pakartokite savo naują slaptažodį.',
	'UsersManager_TheLoginScreen' => 'Prisijungimo langas',
	'UsersManager_DeleteConfirm_js' => 'Ar tikrai norite pašalinti naudotoją %s?',
	'UsersManager_YourUsernameCannotBeChanged' => 'Jūsų naudotojo vardas negali būti pakeistas.',
	'UsersManager_ExceptionLoginExists' => 'Registracijos vardas \'%s\' jau yra.',
	'UsersManager_ExceptionEmailExists' => 'Naudotojas su tokiu el. paštu \'%s\' jau yra.',
	'UsersManager_ExceptionInvalidLoginFormat' => 'Registracijos vardas turi būti sudarytas iš %1$s - %2$s simbolių ir gali turėti raides, skaičius, arba simbolius \'_\', \'-\', \'.\'',
	'UsersManager_ExceptionInvalidEmail' => 'Netinkamas el. pašto formatas.',
	'UsersManager_ExceptionDeleteDoesNotExist' => 'Naudotojas \'%s\' neegzistuoja, todėl negali būti ištrintas.',
	'UsersManager_ExceptionAdminAnonymous' => 'Negalite priskirti \'administratorius\' teisių \'anonimas\' naudotojui.',
	'UsersManager_ExceptionEditAnonymous' => 'Naudotojas \'anonimas\' negali būti keičiamas ar šalinamas. Jis naudojamas nustatyti naudotoją, kuris dar neprisijungęs. Pavyzdžiui, Jūs galite padaryti savo statistinius duomenis viešais suteikdami \'matyti\' teises naudotojui \'anonimas\'.',
	'UsersManager_ExceptionSuperUser' => 'Pageidaujamas naudotojas yra Super Naudotojas, todėl negali būti klausiamas, keičiamas ar šalinamas per API sąsają. Super Naudotojo duomenis galite keisti rankiniu būdu Piwik konfigūraciniame faile.',
	'UsersManager_ExceptionUserDoesNotExist' => 'Naudotojas \'%s\' neegzistuoja.',
	'UsersManager_ExceptionAccessValues' => 'Parametras access privalo turėti vieną iš šių reikšmių: [ %s ]',
	'VisitFrequency_PluginDescription' => 'Parodo įvairią statistiką apie sugrįžtančius bei pirmą kartą apsilankančius lankytojus.',
	'VisitFrequency_Evolution' => 'Raida periodu',
	'VisitFrequency_ColumnReturningVisits' => 'Sugrįžtančių apsilankymai',
	'VisitFrequency_ColumnActionsByReturningVisits' => 'Sugrįžtančių veiksmai',
	'VisitFrequency_ColumnAverageVisitDurationForReturningVisitors' => 'Vidutinė sugrįžtančių lankytojų apsilankymo trukmė (sek.)',
	'VisitFrequency_ColumnBounceRateForReturningVisits' => 'Šoklumo reitingas tarp sugrįžtančių',
	'VisitFrequency_ColumnAvgActionsPerReturningVisit' => 'Vidutiniškai atlikta sugrįžtančio lankytojo veiksmų',
	'VisitFrequency_ReturnVisits' => '%s sugrįžtančių apsilankymai',
	'VisitFrequency_ReturnActions' => '%s sugrįžtančių veiksmai',
	'VisitFrequency_ReturnAvgActions' => '%s veiksmų iš sugrįžtančio lankytojo',
	'VisitFrequency_ReturnAverageVisitDuration' => '%s sugrįžtančio lankytojo apsilankymo trukmės vidurkis',
	'VisitFrequency_ReturnBounceRate' => '%s šoklumo reitingas tarp sugrįžtančių (paliko svetainę po pirmojo puslapio)',
	'VisitFrequency_WidgetOverview' => 'Pasikartojimų peržiūra',
	'VisitFrequency_WidgetGraphReturning' => 'Sugrįžtančių grafikas',
	'VisitFrequency_SubmenuFrequency' => 'Pasikartojimai',
	'VisitorGenerator_VisitorGenerator' => 'Apsilankymų generatorius',
	'VisitorInterest_PluginDescription' => 'Parodo lankytojų susidomėjimą: aplankytus puslapius, svetainėje praleistą laiką.',
	'VisitorInterest_VisitsPerDuration' => 'Apsilankymai pagal apsilankymų trukmę',
	'VisitorInterest_VisitsPerNbOfPages' => 'Apsilankymai pagal puslapių kiekį',
	'VisitorInterest_ColumnVisitDuration' => 'Apsilankymo trukmė',
	'VisitorInterest_ColumnPagesPerVisit' => 'Puslapių per apsilankymą',
	'VisitorInterest_WidgetLengths' => 'Apsilankymų trukmė',
	'VisitorInterest_WidgetPages' => 'Puslapių per apsilankymą',
	'VisitorInterest_Engagement' => 'Įsipareigojimai',
	'VisitorInterest_PlusXMin' => '%s min',
	'VisitorInterest_BetweenXYMinutes' => '%1$s-%2$s min.',
	'VisitorInterest_OnePage' => '1 puslapis',
	'VisitorInterest_NPages' => '%s puslapiai',
	'VisitorInterest_BetweenXYSeconds' => '%1$s-%2$ssek.',
	'VisitsSummary_PluginDescription' => 'Parodo pagrindinius analizatoriaus duomenis: apsilankymus, unikalius lankytojus, veiksmų kiekį, šoklumo koeficientą ir t.t.',
	'VisitsSummary_VisitsSummary' => 'Apsilankymų suvestinė',
	'VisitsSummary_NbVisits' => '%s apsilankymai',
	'VisitsSummary_NbUniqueVisitors' => '%s unikalūs lankytojai',
	'VisitsSummary_NbActionsDescription' => '%s veiksmai (puslapio peržiūros, atsisiuntimai ir išorinės nuorodos)',
	'VisitsSummary_AverageVisitDuration' => '%s vidutinio apsilankymo trukmė',
	'VisitsSummary_MaxNbActions' => '%s daugiausia veiksmų per apsilankymą',
	'VisitsSummary_NbActionsPerVisit' => '%s veiksmų per apsilankymą',
	'VisitsSummary_NbVisitsBounced' => '%s atsitiktiniai apsilankymai (paliko svetainę po pirmojo puslapio)',
	'VisitsSummary_EvolutionOverLastPeriods' => 'Paskutinio %s raida',
	'VisitsSummary_GenerateTime' => '%s sekundės puslapiui sugeneruoti',
	'VisitsSummary_GenerateQueries' => '%s aktyvuotos užklausos',
	'VisitsSummary_WidgetLastVisits' => 'Paskutinių apsilankymų diagrama',
	'VisitsSummary_WidgetVisits' => 'Apsilankymų peržiūra',
	'VisitsSummary_WidgetLastVisitors' => 'Paskutinių unikalių lankytojų diagrama',
	'VisitsSummary_WidgetOverviewGraph' => 'Peržiūra su diagrama',
	'VisitsSummary_SubmenuOverview' => 'Peržiūra',
	'VisitTime_PluginDescription' => 'Ataskaitos lokaliu ir serverio laiku.',
	'VisitTime_LocalTime' => 'Apsilankymai vietiniu laiku',
	'VisitTime_ServerTime' => 'Apsilankymai serverio laiku',
	'VisitTime_ColumnServerTime' => 'Serverio laikas',
	'VisitTime_ColumnLocalTime' => 'Vietinis laikas',
	'VisitTime_WidgetLocalTime' => 'Apsilankymai vietiniu laiku',
	'VisitTime_WidgetServerTime' => 'Apsilankymai serverio laiku',
	'VisitTime_SubmenuTimes' => 'Laikai',
	'VisitTime_NHour' => '%sh',
	'Widgetize_PluginDescription' => 'Šis papildinys leidžia itin paprastai eksportuoti bet kurį Piwik valdiklį į Jūsų interneto dienoraštį, svetainę ar į Igoogle bei Netvibes!',
	'PDFReports_PluginDescriptionReports' => 'Sukurkite ir atsisiųskite savo ataskaitas arba nustatytike jų kadieninį, kas savaitinį ar mėnesinį atsisiuntimą.',
	'PDFReports_ManageEmailReports' => 'Administruoti ataskaitas',
	'PDFReports_EmailReports' => 'Ataskaitos el. paštu',
	'PDFReports_PDF' => 'PDF',
	'PDFReports_SendReportNow' => 'Siųsti ataskaitą dabar',
	'PDFReports_EmailSchedule' => 'Siuntimo tvarkaraštis',
	'PDFReports_SendReportTo' => 'Siųsti ataskaitą į',
	'PDFReports_ReportFormat' => 'Ataskaitos formatas',
	'PDFReports_SentToMe' => 'Siųsti man',
	'PDFReports_CreateAndScheduleReport' => 'Sukurti ir suplanuoti ataskaitą',
	'PDFReports_WeeklyScheduleHelp' => 'Kas savaitę: ataskaita bus išsiųsta kiekvienos savaitės pirmadienį.',
	'PDFReports_MonthlyScheduleHelp' => 'Kas mėnesį: ataskaita bus išsiųsta kiekvieno mėnesio pirmąją dieną.',
	'PDFReports_AlsoSendReportToTheseEmails' => 'Taip pat siųsti šią ataskaitą šiems adresatams (kiekvienam adresui atskira eilutė)',
	'PDFReports_ReportsIncluded' => 'Įtraukta statistika',
	'PDFReports_CreateReport' => 'Sukurti ataskaitą',
	'PDFReports_UpdateReport' => 'Atnaujinti ataskaitą',
	'PDFReports_PiwikReports' => 'Piwik ataskaitos',
	'PDFReports_DefaultContainingAllReports' => 'Numatytoji ataskaita turi visą pasiekiamą statistiką',
	'PDFReports_EmailHello' => 'Sveiki,',
	'PDFReports_PleaseFindAttachedFile' => 'Prašome peržiūrėti %1$s ataskaitų failą skirtą %2$s.',
	'PDFReports_FrontPage' => 'Pirminis puslapis',
	'PDFReports_TableOfContent' => 'Ataskaitos sąrašas',
	'PDFReports_TopOfReport' => 'Atgal į viršų',
	'PDFReports_Pagination' => 'Puslapis %s iš %s',
);
